# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ListingSummary(object):
    """
    The model for a summary of an Oracle Cloud Infrastructure Marketplace listing.
    """

    #: A constant which can be used with the package_type property of a ListingSummary.
    #: This constant has a value of "ORCHESTRATION"
    PACKAGE_TYPE_ORCHESTRATION = "ORCHESTRATION"

    #: A constant which can be used with the package_type property of a ListingSummary.
    #: This constant has a value of "IMAGE"
    PACKAGE_TYPE_IMAGE = "IMAGE"

    #: A constant which can be used with the pricing_types property of a ListingSummary.
    #: This constant has a value of "FREE"
    PRICING_TYPES_FREE = "FREE"

    #: A constant which can be used with the pricing_types property of a ListingSummary.
    #: This constant has a value of "BYOL"
    PRICING_TYPES_BYOL = "BYOL"

    #: A constant which can be used with the pricing_types property of a ListingSummary.
    #: This constant has a value of "PAYGO"
    PRICING_TYPES_PAYGO = "PAYGO"

    def __init__(self, **kwargs):
        """
        Initializes a new ListingSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ListingSummary.
        :type id: str

        :param name:
            The value to assign to the name property of this ListingSummary.
        :type name: str

        :param short_description:
            The value to assign to the short_description property of this ListingSummary.
        :type short_description: str

        :param tagline:
            The value to assign to the tagline property of this ListingSummary.
        :type tagline: str

        :param icon:
            The value to assign to the icon property of this ListingSummary.
        :type icon: UploadData

        :param package_type:
            The value to assign to the package_type property of this ListingSummary.
            Allowed values for this property are: "ORCHESTRATION", "IMAGE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type package_type: str

        :param pricing_types:
            The value to assign to the pricing_types property of this ListingSummary.
            Allowed values for items in this list are: "FREE", "BYOL", "PAYGO", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type pricing_types: list[str]

        :param regions:
            The value to assign to the regions property of this ListingSummary.
        :type regions: list[Region]

        :param is_featured:
            The value to assign to the is_featured property of this ListingSummary.
        :type is_featured: bool

        :param categories:
            The value to assign to the categories property of this ListingSummary.
        :type categories: list[str]

        :param publisher:
            The value to assign to the publisher property of this ListingSummary.
        :type publisher: PublisherSummary

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'short_description': 'str',
            'tagline': 'str',
            'icon': 'UploadData',
            'package_type': 'str',
            'pricing_types': 'list[str]',
            'regions': 'list[Region]',
            'is_featured': 'bool',
            'categories': 'list[str]',
            'publisher': 'PublisherSummary'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'short_description': 'shortDescription',
            'tagline': 'tagline',
            'icon': 'icon',
            'package_type': 'packageType',
            'pricing_types': 'pricingTypes',
            'regions': 'regions',
            'is_featured': 'isFeatured',
            'categories': 'categories',
            'publisher': 'publisher'
        }

        self._id = None
        self._name = None
        self._short_description = None
        self._tagline = None
        self._icon = None
        self._package_type = None
        self._pricing_types = None
        self._regions = None
        self._is_featured = None
        self._categories = None
        self._publisher = None

    @property
    def id(self):
        """
        Gets the id of this ListingSummary.
        The unique identifier for the listing in Marketplace.


        :return: The id of this ListingSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ListingSummary.
        The unique identifier for the listing in Marketplace.


        :param id: The id of this ListingSummary.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ListingSummary.
        The name of the listing.


        :return: The name of this ListingSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ListingSummary.
        The name of the listing.


        :param name: The name of this ListingSummary.
        :type: str
        """
        self._name = name

    @property
    def short_description(self):
        """
        Gets the short_description of this ListingSummary.
        A short description of the listing.


        :return: The short_description of this ListingSummary.
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """
        Sets the short_description of this ListingSummary.
        A short description of the listing.


        :param short_description: The short_description of this ListingSummary.
        :type: str
        """
        self._short_description = short_description

    @property
    def tagline(self):
        """
        Gets the tagline of this ListingSummary.
        The tagline of the listing.


        :return: The tagline of this ListingSummary.
        :rtype: str
        """
        return self._tagline

    @tagline.setter
    def tagline(self, tagline):
        """
        Sets the tagline of this ListingSummary.
        The tagline of the listing.


        :param tagline: The tagline of this ListingSummary.
        :type: str
        """
        self._tagline = tagline

    @property
    def icon(self):
        """
        Gets the icon of this ListingSummary.

        :return: The icon of this ListingSummary.
        :rtype: UploadData
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """
        Sets the icon of this ListingSummary.

        :param icon: The icon of this ListingSummary.
        :type: UploadData
        """
        self._icon = icon

    @property
    def package_type(self):
        """
        Gets the package_type of this ListingSummary.
        The listing's package type.

        Allowed values for this property are: "ORCHESTRATION", "IMAGE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The package_type of this ListingSummary.
        :rtype: str
        """
        return self._package_type

    @package_type.setter
    def package_type(self, package_type):
        """
        Sets the package_type of this ListingSummary.
        The listing's package type.


        :param package_type: The package_type of this ListingSummary.
        :type: str
        """
        allowed_values = ["ORCHESTRATION", "IMAGE"]
        if not value_allowed_none_or_none_sentinel(package_type, allowed_values):
            package_type = 'UNKNOWN_ENUM_VALUE'
        self._package_type = package_type

    @property
    def pricing_types(self):
        """
        Gets the pricing_types of this ListingSummary.
        Summary of the pricing types available across all packages in the listing.

        Allowed values for items in this list are: "FREE", "BYOL", "PAYGO", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The pricing_types of this ListingSummary.
        :rtype: list[str]
        """
        return self._pricing_types

    @pricing_types.setter
    def pricing_types(self, pricing_types):
        """
        Sets the pricing_types of this ListingSummary.
        Summary of the pricing types available across all packages in the listing.


        :param pricing_types: The pricing_types of this ListingSummary.
        :type: list[str]
        """
        allowed_values = ["FREE", "BYOL", "PAYGO"]
        if pricing_types:
            pricing_types[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in pricing_types]
        self._pricing_types = pricing_types

    @property
    def regions(self):
        """
        Gets the regions of this ListingSummary.
        The regions where the listing is eligible to be deployed.


        :return: The regions of this ListingSummary.
        :rtype: list[Region]
        """
        return self._regions

    @regions.setter
    def regions(self, regions):
        """
        Sets the regions of this ListingSummary.
        The regions where the listing is eligible to be deployed.


        :param regions: The regions of this ListingSummary.
        :type: list[Region]
        """
        self._regions = regions

    @property
    def is_featured(self):
        """
        Gets the is_featured of this ListingSummary.
        Indicates whether the listing is featured.


        :return: The is_featured of this ListingSummary.
        :rtype: bool
        """
        return self._is_featured

    @is_featured.setter
    def is_featured(self, is_featured):
        """
        Sets the is_featured of this ListingSummary.
        Indicates whether the listing is featured.


        :param is_featured: The is_featured of this ListingSummary.
        :type: bool
        """
        self._is_featured = is_featured

    @property
    def categories(self):
        """
        Gets the categories of this ListingSummary.
        Product categories that the listing belongs to.


        :return: The categories of this ListingSummary.
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """
        Sets the categories of this ListingSummary.
        Product categories that the listing belongs to.


        :param categories: The categories of this ListingSummary.
        :type: list[str]
        """
        self._categories = categories

    @property
    def publisher(self):
        """
        Gets the publisher of this ListingSummary.

        :return: The publisher of this ListingSummary.
        :rtype: PublisherSummary
        """
        return self._publisher

    @publisher.setter
    def publisher(self, publisher):
        """
        Sets the publisher of this ListingSummary.

        :param publisher: The publisher of this ListingSummary.
        :type: PublisherSummary
        """
        self._publisher = publisher

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateLogAnalyticsObjectCollectionRuleDetails(object):
    """
    To update the attributes of an Object Storage based collection rule.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateLogAnalyticsObjectCollectionRuleDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type description: str

        :param log_group_id:
            The value to assign to the log_group_id property of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type log_group_id: str

        :param log_source_name:
            The value to assign to the log_source_name property of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type log_source_name: str

        :param entity_id:
            The value to assign to the entity_id property of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type entity_id: str

        :param char_encoding:
            The value to assign to the char_encoding property of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type char_encoding: str

        :param overrides:
            The value to assign to the overrides property of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type overrides: dict(str, list[PropertyOverride])

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type freeform_tags: dict(str, str)

        """
        self.swagger_types = {
            'description': 'str',
            'log_group_id': 'str',
            'log_source_name': 'str',
            'entity_id': 'str',
            'char_encoding': 'str',
            'overrides': 'dict(str, list[PropertyOverride])',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)'
        }

        self.attribute_map = {
            'description': 'description',
            'log_group_id': 'logGroupId',
            'log_source_name': 'logSourceName',
            'entity_id': 'entityId',
            'char_encoding': 'charEncoding',
            'overrides': 'overrides',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags'
        }

        self._description = None
        self._log_group_id = None
        self._log_source_name = None
        self._entity_id = None
        self._char_encoding = None
        self._overrides = None
        self._defined_tags = None
        self._freeform_tags = None

    @property
    def description(self):
        """
        Gets the description of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        A string that describes the details of the rule.
        Avoid entering confidential information.


        :return: The description of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        A string that describes the details of the rule.
        Avoid entering confidential information.


        :param description: The description of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._description = description

    @property
    def log_group_id(self):
        """
        Gets the log_group_id of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        Log Analytics Log group OCID to associate the processed logs with.


        :return: The log_group_id of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._log_group_id

    @log_group_id.setter
    def log_group_id(self, log_group_id):
        """
        Sets the log_group_id of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        Log Analytics Log group OCID to associate the processed logs with.


        :param log_group_id: The log_group_id of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._log_group_id = log_group_id

    @property
    def log_source_name(self):
        """
        Gets the log_source_name of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        Name of the Log Analytics Source to use for the processing.


        :return: The log_source_name of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._log_source_name

    @log_source_name.setter
    def log_source_name(self, log_source_name):
        """
        Sets the log_source_name of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        Name of the Log Analytics Source to use for the processing.


        :param log_source_name: The log_source_name of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._log_source_name = log_source_name

    @property
    def entity_id(self):
        """
        Gets the entity_id of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        Log Analytics entity OCID. Associates the processed logs with the given entity (optional).


        :return: The entity_id of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """
        Sets the entity_id of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        Log Analytics entity OCID. Associates the processed logs with the given entity (optional).


        :param entity_id: The entity_id of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._entity_id = entity_id

    @property
    def char_encoding(self):
        """
        Gets the char_encoding of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        An optional character encoding to aid in detecting the character encoding of the contents of the objects while processing.
        It is recommended to set this value as ISO_8589_1 when configuring content of the objects having more numeric characters,
        and very few alphabets.
        For e.g. this applies when configuring VCN Flow Logs.


        :return: The char_encoding of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._char_encoding

    @char_encoding.setter
    def char_encoding(self, char_encoding):
        """
        Sets the char_encoding of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        An optional character encoding to aid in detecting the character encoding of the contents of the objects while processing.
        It is recommended to set this value as ISO_8589_1 when configuring content of the objects having more numeric characters,
        and very few alphabets.
        For e.g. this applies when configuring VCN Flow Logs.


        :param char_encoding: The char_encoding of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._char_encoding = char_encoding

    @property
    def overrides(self):
        """
        Gets the overrides of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        Use this to override some property values which are defined at bucket level to the scope of object.
        Supported propeties for override are, logSourceName, charEncoding.
        Supported matchType for override are \"contains\".


        :return: The overrides of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: dict(str, list[PropertyOverride])
        """
        return self._overrides

    @overrides.setter
    def overrides(self, overrides):
        """
        Sets the overrides of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        Use this to override some property values which are defined at bucket level to the scope of object.
        Supported propeties for override are, logSourceName, charEncoding.
        Supported matchType for override are \"contains\".


        :param overrides: The overrides of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type: dict(str, list[PropertyOverride])
        """
        self._overrides = overrides

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this UpdateLogAnalyticsObjectCollectionRuleDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ShapeNetworkingBandwidthOptions(object):
    """
    For a flexible shape, the amount of networking bandwidth available for instances that use this shape.

    If this field is null, then this shape has a fixed amount of bandwidth equivalent to `networkingBandwidthInGbps`.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ShapeNetworkingBandwidthOptions object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param min_in_gbps:
            The value to assign to the min_in_gbps property of this ShapeNetworkingBandwidthOptions.
        :type min_in_gbps: float

        :param max_in_gbps:
            The value to assign to the max_in_gbps property of this ShapeNetworkingBandwidthOptions.
        :type max_in_gbps: float

        :param default_per_ocpu_in_gbps:
            The value to assign to the default_per_ocpu_in_gbps property of this ShapeNetworkingBandwidthOptions.
        :type default_per_ocpu_in_gbps: float

        """
        self.swagger_types = {
            'min_in_gbps': 'float',
            'max_in_gbps': 'float',
            'default_per_ocpu_in_gbps': 'float'
        }

        self.attribute_map = {
            'min_in_gbps': 'minInGbps',
            'max_in_gbps': 'maxInGbps',
            'default_per_ocpu_in_gbps': 'defaultPerOcpuInGbps'
        }

        self._min_in_gbps = None
        self._max_in_gbps = None
        self._default_per_ocpu_in_gbps = None

    @property
    def min_in_gbps(self):
        """
        Gets the min_in_gbps of this ShapeNetworkingBandwidthOptions.
        The minimum amount of networking bandwidth, in gigabits per second.


        :return: The min_in_gbps of this ShapeNetworkingBandwidthOptions.
        :rtype: float
        """
        return self._min_in_gbps

    @min_in_gbps.setter
    def min_in_gbps(self, min_in_gbps):
        """
        Sets the min_in_gbps of this ShapeNetworkingBandwidthOptions.
        The minimum amount of networking bandwidth, in gigabits per second.


        :param min_in_gbps: The min_in_gbps of this ShapeNetworkingBandwidthOptions.
        :type: float
        """
        self._min_in_gbps = min_in_gbps

    @property
    def max_in_gbps(self):
        """
        Gets the max_in_gbps of this ShapeNetworkingBandwidthOptions.
        The maximum amount of networking bandwidth, in gigabits per second.


        :return: The max_in_gbps of this ShapeNetworkingBandwidthOptions.
        :rtype: float
        """
        return self._max_in_gbps

    @max_in_gbps.setter
    def max_in_gbps(self, max_in_gbps):
        """
        Sets the max_in_gbps of this ShapeNetworkingBandwidthOptions.
        The maximum amount of networking bandwidth, in gigabits per second.


        :param max_in_gbps: The max_in_gbps of this ShapeNetworkingBandwidthOptions.
        :type: float
        """
        self._max_in_gbps = max_in_gbps

    @property
    def default_per_ocpu_in_gbps(self):
        """
        Gets the default_per_ocpu_in_gbps of this ShapeNetworkingBandwidthOptions.
        The default amount of networking bandwidth per OCPU, in gigabits per second.


        :return: The default_per_ocpu_in_gbps of this ShapeNetworkingBandwidthOptions.
        :rtype: float
        """
        return self._default_per_ocpu_in_gbps

    @default_per_ocpu_in_gbps.setter
    def default_per_ocpu_in_gbps(self, default_per_ocpu_in_gbps):
        """
        Sets the default_per_ocpu_in_gbps of this ShapeNetworkingBandwidthOptions.
        The default amount of networking bandwidth per OCPU, in gigabits per second.


        :param default_per_ocpu_in_gbps: The default_per_ocpu_in_gbps of this ShapeNetworkingBandwidthOptions.
        :type: float
        """
        self._default_per_ocpu_in_gbps = default_per_ocpu_in_gbps

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsConfigWorkRequest(object):
    """
    LogAnalyticsConfigWorkRequest
    """

    #: A constant which can be used with the operation_type property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "CREATE_ASSOCIATIONS"
    OPERATION_TYPE_CREATE_ASSOCIATIONS = "CREATE_ASSOCIATIONS"

    #: A constant which can be used with the operation_type property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "DELETE_ASSOCIATIONS"
    OPERATION_TYPE_DELETE_ASSOCIATIONS = "DELETE_ASSOCIATIONS"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "ACCEPTED"
    LIFECYCLE_STATE_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "IN_PROGRESS"
    LIFECYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsConfigWorkRequest object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this LogAnalyticsConfigWorkRequest.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this LogAnalyticsConfigWorkRequest.
        :type compartment_id: str

        :param operation_type:
            The value to assign to the operation_type property of this LogAnalyticsConfigWorkRequest.
            Allowed values for this property are: "CREATE_ASSOCIATIONS", "DELETE_ASSOCIATIONS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type operation_type: str

        :param payload:
            The value to assign to the payload property of this LogAnalyticsConfigWorkRequest.
        :type payload: list[LogAnalyticsConfigWorkRequestPayload]

        :param percent_complete:
            The value to assign to the percent_complete property of this LogAnalyticsConfigWorkRequest.
        :type percent_complete: int

        :param time_started:
            The value to assign to the time_started property of this LogAnalyticsConfigWorkRequest.
        :type time_started: datetime

        :param time_accepted:
            The value to assign to the time_accepted property of this LogAnalyticsConfigWorkRequest.
        :type time_accepted: datetime

        :param time_finished:
            The value to assign to the time_finished property of this LogAnalyticsConfigWorkRequest.
        :type time_finished: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this LogAnalyticsConfigWorkRequest.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'operation_type': 'str',
            'payload': 'list[LogAnalyticsConfigWorkRequestPayload]',
            'percent_complete': 'int',
            'time_started': 'datetime',
            'time_accepted': 'datetime',
            'time_finished': 'datetime',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'operation_type': 'operationType',
            'payload': 'payload',
            'percent_complete': 'percentComplete',
            'time_started': 'timeStarted',
            'time_accepted': 'timeAccepted',
            'time_finished': 'timeFinished',
            'lifecycle_state': 'lifecycleState'
        }

        self._id = None
        self._compartment_id = None
        self._operation_type = None
        self._payload = None
        self._percent_complete = None
        self._time_started = None
        self._time_accepted = None
        self._time_finished = None
        self._lifecycle_state = None

    @property
    def id(self):
        """
        Gets the id of this LogAnalyticsConfigWorkRequest.
        workrequest id


        :return: The id of this LogAnalyticsConfigWorkRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LogAnalyticsConfigWorkRequest.
        workrequest id


        :param id: The id of this LogAnalyticsConfigWorkRequest.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this LogAnalyticsConfigWorkRequest.
        compartment id


        :return: The compartment_id of this LogAnalyticsConfigWorkRequest.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this LogAnalyticsConfigWorkRequest.
        compartment id


        :param compartment_id: The compartment_id of this LogAnalyticsConfigWorkRequest.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def operation_type(self):
        """
        Gets the operation_type of this LogAnalyticsConfigWorkRequest.
        operation type

        Allowed values for this property are: "CREATE_ASSOCIATIONS", "DELETE_ASSOCIATIONS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The operation_type of this LogAnalyticsConfigWorkRequest.
        :rtype: str
        """
        return self._operation_type

    @operation_type.setter
    def operation_type(self, operation_type):
        """
        Sets the operation_type of this LogAnalyticsConfigWorkRequest.
        operation type


        :param operation_type: The operation_type of this LogAnalyticsConfigWorkRequest.
        :type: str
        """
        allowed_values = ["CREATE_ASSOCIATIONS", "DELETE_ASSOCIATIONS"]
        if not value_allowed_none_or_none_sentinel(operation_type, allowed_values):
            operation_type = 'UNKNOWN_ENUM_VALUE'
        self._operation_type = operation_type

    @property
    def payload(self):
        """
        Gets the payload of this LogAnalyticsConfigWorkRequest.
        list of log group summary objects


        :return: The payload of this LogAnalyticsConfigWorkRequest.
        :rtype: list[LogAnalyticsConfigWorkRequestPayload]
        """
        return self._payload

    @payload.setter
    def payload(self, payload):
        """
        Sets the payload of this LogAnalyticsConfigWorkRequest.
        list of log group summary objects


        :param payload: The payload of this LogAnalyticsConfigWorkRequest.
        :type: list[LogAnalyticsConfigWorkRequestPayload]
        """
        self._payload = payload

    @property
    def percent_complete(self):
        """
        Gets the percent_complete of this LogAnalyticsConfigWorkRequest.
        percentage complete


        :return: The percent_complete of this LogAnalyticsConfigWorkRequest.
        :rtype: int
        """
        return self._percent_complete

    @percent_complete.setter
    def percent_complete(self, percent_complete):
        """
        Sets the percent_complete of this LogAnalyticsConfigWorkRequest.
        percentage complete


        :param percent_complete: The percent_complete of this LogAnalyticsConfigWorkRequest.
        :type: int
        """
        self._percent_complete = percent_complete

    @property
    def time_started(self):
        """
        Gets the time_started of this LogAnalyticsConfigWorkRequest.
        when the work request was started


        :return: The time_started of this LogAnalyticsConfigWorkRequest.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this LogAnalyticsConfigWorkRequest.
        when the work request was started


        :param time_started: The time_started of this LogAnalyticsConfigWorkRequest.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_accepted(self):
        """
        Gets the time_accepted of this LogAnalyticsConfigWorkRequest.
        when the work request was accepted


        :return: The time_accepted of this LogAnalyticsConfigWorkRequest.
        :rtype: datetime
        """
        return self._time_accepted

    @time_accepted.setter
    def time_accepted(self, time_accepted):
        """
        Sets the time_accepted of this LogAnalyticsConfigWorkRequest.
        when the work request was accepted


        :param time_accepted: The time_accepted of this LogAnalyticsConfigWorkRequest.
        :type: datetime
        """
        self._time_accepted = time_accepted

    @property
    def time_finished(self):
        """
        Gets the time_finished of this LogAnalyticsConfigWorkRequest.
        when the work request finished


        :return: The time_finished of this LogAnalyticsConfigWorkRequest.
        :rtype: datetime
        """
        return self._time_finished

    @time_finished.setter
    def time_finished(self, time_finished):
        """
        Sets the time_finished of this LogAnalyticsConfigWorkRequest.
        when the work request finished


        :param time_finished: The time_finished of this LogAnalyticsConfigWorkRequest.
        :type: datetime
        """
        self._time_finished = time_finished

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this LogAnalyticsConfigWorkRequest.
        status

        Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this LogAnalyticsConfigWorkRequest.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this LogAnalyticsConfigWorkRequest.
        status


        :param lifecycle_state: The lifecycle_state of this LogAnalyticsConfigWorkRequest.
        :type: str
        """
        allowed_values = ["ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Zone(object):
    """
    A DNS zone.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the zone_type property of a Zone.
    #: This constant has a value of "PRIMARY"
    ZONE_TYPE_PRIMARY = "PRIMARY"

    #: A constant which can be used with the zone_type property of a Zone.
    #: This constant has a value of "SECONDARY"
    ZONE_TYPE_SECONDARY = "SECONDARY"

    #: A constant which can be used with the lifecycle_state property of a Zone.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Zone.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Zone.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Zone.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Zone.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new Zone object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this Zone.
        :type name: str

        :param zone_type:
            The value to assign to the zone_type property of this Zone.
            Allowed values for this property are: "PRIMARY", "SECONDARY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type zone_type: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Zone.
        :type compartment_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Zone.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Zone.
        :type defined_tags: dict(str, dict(str, object))

        :param external_masters:
            The value to assign to the external_masters property of this Zone.
        :type external_masters: list[ExternalMaster]

        :param self_uri:
            The value to assign to the self_uri property of this Zone.
        :type self_uri: str

        :param id:
            The value to assign to the id property of this Zone.
        :type id: str

        :param time_created:
            The value to assign to the time_created property of this Zone.
        :type time_created: datetime

        :param version:
            The value to assign to the version property of this Zone.
        :type version: str

        :param serial:
            The value to assign to the serial property of this Zone.
        :type serial: int

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Zone.
            Allowed values for this property are: "ACTIVE", "CREATING", "DELETED", "DELETING", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param nameservers:
            The value to assign to the nameservers property of this Zone.
        :type nameservers: list[Nameserver]

        """
        self.swagger_types = {
            'name': 'str',
            'zone_type': 'str',
            'compartment_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'external_masters': 'list[ExternalMaster]',
            'self_uri': 'str',
            'id': 'str',
            'time_created': 'datetime',
            'version': 'str',
            'serial': 'int',
            'lifecycle_state': 'str',
            'nameservers': 'list[Nameserver]'
        }

        self.attribute_map = {
            'name': 'name',
            'zone_type': 'zoneType',
            'compartment_id': 'compartmentId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'external_masters': 'externalMasters',
            'self_uri': 'self',
            'id': 'id',
            'time_created': 'timeCreated',
            'version': 'version',
            'serial': 'serial',
            'lifecycle_state': 'lifecycleState',
            'nameservers': 'nameservers'
        }

        self._name = None
        self._zone_type = None
        self._compartment_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._external_masters = None
        self._self_uri = None
        self._id = None
        self._time_created = None
        self._version = None
        self._serial = None
        self._lifecycle_state = None
        self._nameservers = None

    @property
    def name(self):
        """
        Gets the name of this Zone.
        The name of the zone.


        :return: The name of this Zone.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Zone.
        The name of the zone.


        :param name: The name of this Zone.
        :type: str
        """
        self._name = name

    @property
    def zone_type(self):
        """
        Gets the zone_type of this Zone.
        The type of the zone. Must be either `PRIMARY` or `SECONDARY`.

        Allowed values for this property are: "PRIMARY", "SECONDARY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The zone_type of this Zone.
        :rtype: str
        """
        return self._zone_type

    @zone_type.setter
    def zone_type(self, zone_type):
        """
        Sets the zone_type of this Zone.
        The type of the zone. Must be either `PRIMARY` or `SECONDARY`.


        :param zone_type: The zone_type of this Zone.
        :type: str
        """
        allowed_values = ["PRIMARY", "SECONDARY"]
        if not value_allowed_none_or_none_sentinel(zone_type, allowed_values):
            zone_type = 'UNKNOWN_ENUM_VALUE'
        self._zone_type = zone_type

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this Zone.
        The OCID of the compartment containing the zone.


        :return: The compartment_id of this Zone.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Zone.
        The OCID of the compartment containing the zone.


        :param compartment_id: The compartment_id of this Zone.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Zone.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.


        **Example:** `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Zone.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Zone.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.


        **Example:** `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Zone.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Zone.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.


        **Example:** `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Zone.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Zone.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.


        **Example:** `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Zone.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def external_masters(self):
        """
        Gets the external_masters of this Zone.
        External master servers for the zone. `externalMasters` becomes a
        required parameter when the `zoneType` value is `SECONDARY`.


        :return: The external_masters of this Zone.
        :rtype: list[ExternalMaster]
        """
        return self._external_masters

    @external_masters.setter
    def external_masters(self, external_masters):
        """
        Sets the external_masters of this Zone.
        External master servers for the zone. `externalMasters` becomes a
        required parameter when the `zoneType` value is `SECONDARY`.


        :param external_masters: The external_masters of this Zone.
        :type: list[ExternalMaster]
        """
        self._external_masters = external_masters

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Zone.
        The canonical absolute URL of the resource.


        :return: The self_uri of this Zone.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Zone.
        The canonical absolute URL of the resource.


        :param self_uri: The self_uri of this Zone.
        :type: str
        """
        self._self_uri = self_uri

    @property
    def id(self):
        """
        Gets the id of this Zone.
        The OCID of the zone.


        :return: The id of this Zone.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Zone.
        The OCID of the zone.


        :param id: The id of this Zone.
        :type: str
        """
        self._id = id

    @property
    def time_created(self):
        """
        Gets the time_created of this Zone.
        The date and time the resource was created in \"YYYY-MM-ddThh:mmZ\" format
        with a Z offset, as defined by RFC 3339.

        **Example:** `2016-07-22T17:23:59:60Z`


        :return: The time_created of this Zone.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Zone.
        The date and time the resource was created in \"YYYY-MM-ddThh:mmZ\" format
        with a Z offset, as defined by RFC 3339.

        **Example:** `2016-07-22T17:23:59:60Z`


        :param time_created: The time_created of this Zone.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def version(self):
        """
        Gets the version of this Zone.
        Version is the never-repeating, totally-orderable, version of the
        zone, from which the serial field of the zone's SOA record is
        derived.


        :return: The version of this Zone.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Zone.
        Version is the never-repeating, totally-orderable, version of the
        zone, from which the serial field of the zone's SOA record is
        derived.


        :param version: The version of this Zone.
        :type: str
        """
        self._version = version

    @property
    def serial(self):
        """
        Gets the serial of this Zone.
        The current serial of the zone. As seen in the zone's SOA record.


        :return: The serial of this Zone.
        :rtype: int
        """
        return self._serial

    @serial.setter
    def serial(self, serial):
        """
        Sets the serial of this Zone.
        The current serial of the zone. As seen in the zone's SOA record.


        :param serial: The serial of this Zone.
        :type: int
        """
        self._serial = serial

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Zone.
        The current state of the zone resource.

        Allowed values for this property are: "ACTIVE", "CREATING", "DELETED", "DELETING", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Zone.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Zone.
        The current state of the zone resource.


        :param lifecycle_state: The lifecycle_state of this Zone.
        :type: str
        """
        allowed_values = ["ACTIVE", "CREATING", "DELETED", "DELETING", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def nameservers(self):
        """
        Gets the nameservers of this Zone.
        The authoritative nameservers for the zone.


        :return: The nameservers of this Zone.
        :rtype: list[Nameserver]
        """
        return self._nameservers

    @nameservers.setter
    def nameservers(self, nameservers):
        """
        Sets the nameservers of this Zone.
        The authoritative nameservers for the zone.


        :param nameservers: The nameservers of this Zone.
        :type: list[Nameserver]
        """
        self._nameservers = nameservers

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .unified_agent_parser import UnifiedAgentParser
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UnifiedAgentSyslogParser(UnifiedAgentParser):
    """
    Syslog Parser
    """

    #: A constant which can be used with the message_format property of a UnifiedAgentSyslogParser.
    #: This constant has a value of "RFC3164"
    MESSAGE_FORMAT_RFC3164 = "RFC3164"

    #: A constant which can be used with the message_format property of a UnifiedAgentSyslogParser.
    #: This constant has a value of "RFC5424"
    MESSAGE_FORMAT_RFC5424 = "RFC5424"

    #: A constant which can be used with the message_format property of a UnifiedAgentSyslogParser.
    #: This constant has a value of "AUTO"
    MESSAGE_FORMAT_AUTO = "AUTO"

    #: A constant which can be used with the syslog_parser_type property of a UnifiedAgentSyslogParser.
    #: This constant has a value of "STRING"
    SYSLOG_PARSER_TYPE_STRING = "STRING"

    #: A constant which can be used with the syslog_parser_type property of a UnifiedAgentSyslogParser.
    #: This constant has a value of "REGEXP"
    SYSLOG_PARSER_TYPE_REGEXP = "REGEXP"

    def __init__(self, **kwargs):
        """
        Initializes a new UnifiedAgentSyslogParser object with values from keyword arguments. The default value of the :py:attr:`~oci.logging.models.UnifiedAgentSyslogParser.parser_type` attribute
        of this class is ``SYSLOG`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param parser_type:
            The value to assign to the parser_type property of this UnifiedAgentSyslogParser.
            Allowed values for this property are: "AUDITD", "JSON", "TSV", "CSV", "NONE", "SYSLOG", "APACHE2", "APACHE_ERROR", "MSGPACK", "REGEXP", "MULTILINE", "GROK", "MULTILINE_GROK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type parser_type: str

        :param field_time_key:
            The value to assign to the field_time_key property of this UnifiedAgentSyslogParser.
        :type field_time_key: str

        :param types:
            The value to assign to the types property of this UnifiedAgentSyslogParser.
        :type types: dict(str, str)

        :param null_value_pattern:
            The value to assign to the null_value_pattern property of this UnifiedAgentSyslogParser.
        :type null_value_pattern: str

        :param is_null_empty_string:
            The value to assign to the is_null_empty_string property of this UnifiedAgentSyslogParser.
        :type is_null_empty_string: bool

        :param is_estimate_current_event:
            The value to assign to the is_estimate_current_event property of this UnifiedAgentSyslogParser.
        :type is_estimate_current_event: bool

        :param is_keep_time_key:
            The value to assign to the is_keep_time_key property of this UnifiedAgentSyslogParser.
        :type is_keep_time_key: bool

        :param timeout_in_milliseconds:
            The value to assign to the timeout_in_milliseconds property of this UnifiedAgentSyslogParser.
        :type timeout_in_milliseconds: int

        :param time_format:
            The value to assign to the time_format property of this UnifiedAgentSyslogParser.
        :type time_format: str

        :param rfc5424_time_format:
            The value to assign to the rfc5424_time_format property of this UnifiedAgentSyslogParser.
        :type rfc5424_time_format: str

        :param message_format:
            The value to assign to the message_format property of this UnifiedAgentSyslogParser.
            Allowed values for this property are: "RFC3164", "RFC5424", "AUTO", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type message_format: str

        :param is_with_priority:
            The value to assign to the is_with_priority property of this UnifiedAgentSyslogParser.
        :type is_with_priority: bool

        :param is_support_colonless_ident:
            The value to assign to the is_support_colonless_ident property of this UnifiedAgentSyslogParser.
        :type is_support_colonless_ident: bool

        :param syslog_parser_type:
            The value to assign to the syslog_parser_type property of this UnifiedAgentSyslogParser.
            Allowed values for this property are: "STRING", "REGEXP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type syslog_parser_type: str

        """
        self.swagger_types = {
            'parser_type': 'str',
            'field_time_key': 'str',
            'types': 'dict(str, str)',
            'null_value_pattern': 'str',
            'is_null_empty_string': 'bool',
            'is_estimate_current_event': 'bool',
            'is_keep_time_key': 'bool',
            'timeout_in_milliseconds': 'int',
            'time_format': 'str',
            'rfc5424_time_format': 'str',
            'message_format': 'str',
            'is_with_priority': 'bool',
            'is_support_colonless_ident': 'bool',
            'syslog_parser_type': 'str'
        }

        self.attribute_map = {
            'parser_type': 'parserType',
            'field_time_key': 'fieldTimeKey',
            'types': 'types',
            'null_value_pattern': 'nullValuePattern',
            'is_null_empty_string': 'isNullEmptyString',
            'is_estimate_current_event': 'isEstimateCurrentEvent',
            'is_keep_time_key': 'isKeepTimeKey',
            'timeout_in_milliseconds': 'timeoutInMilliseconds',
            'time_format': 'timeFormat',
            'rfc5424_time_format': 'rfc5424TimeFormat',
            'message_format': 'messageFormat',
            'is_with_priority': 'isWithPriority',
            'is_support_colonless_ident': 'isSupportColonlessIdent',
            'syslog_parser_type': 'syslogParserType'
        }

        self._parser_type = None
        self._field_time_key = None
        self._types = None
        self._null_value_pattern = None
        self._is_null_empty_string = None
        self._is_estimate_current_event = None
        self._is_keep_time_key = None
        self._timeout_in_milliseconds = None
        self._time_format = None
        self._rfc5424_time_format = None
        self._message_format = None
        self._is_with_priority = None
        self._is_support_colonless_ident = None
        self._syslog_parser_type = None
        self._parser_type = 'SYSLOG'

    @property
    def time_format(self):
        """
        Gets the time_format of this UnifiedAgentSyslogParser.

        :return: The time_format of this UnifiedAgentSyslogParser.
        :rtype: str
        """
        return self._time_format

    @time_format.setter
    def time_format(self, time_format):
        """
        Sets the time_format of this UnifiedAgentSyslogParser.

        :param time_format: The time_format of this UnifiedAgentSyslogParser.
        :type: str
        """
        self._time_format = time_format

    @property
    def rfc5424_time_format(self):
        """
        Gets the rfc5424_time_format of this UnifiedAgentSyslogParser.

        :return: The rfc5424_time_format of this UnifiedAgentSyslogParser.
        :rtype: str
        """
        return self._rfc5424_time_format

    @rfc5424_time_format.setter
    def rfc5424_time_format(self, rfc5424_time_format):
        """
        Sets the rfc5424_time_format of this UnifiedAgentSyslogParser.

        :param rfc5424_time_format: The rfc5424_time_format of this UnifiedAgentSyslogParser.
        :type: str
        """
        self._rfc5424_time_format = rfc5424_time_format

    @property
    def message_format(self):
        """
        Gets the message_format of this UnifiedAgentSyslogParser.
        Allowed values for this property are: "RFC3164", "RFC5424", "AUTO", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The message_format of this UnifiedAgentSyslogParser.
        :rtype: str
        """
        return self._message_format

    @message_format.setter
    def message_format(self, message_format):
        """
        Sets the message_format of this UnifiedAgentSyslogParser.

        :param message_format: The message_format of this UnifiedAgentSyslogParser.
        :type: str
        """
        allowed_values = ["RFC3164", "RFC5424", "AUTO"]
        if not value_allowed_none_or_none_sentinel(message_format, allowed_values):
            message_format = 'UNKNOWN_ENUM_VALUE'
        self._message_format = message_format

    @property
    def is_with_priority(self):
        """
        Gets the is_with_priority of this UnifiedAgentSyslogParser.

        :return: The is_with_priority of this UnifiedAgentSyslogParser.
        :rtype: bool
        """
        return self._is_with_priority

    @is_with_priority.setter
    def is_with_priority(self, is_with_priority):
        """
        Sets the is_with_priority of this UnifiedAgentSyslogParser.

        :param is_with_priority: The is_with_priority of this UnifiedAgentSyslogParser.
        :type: bool
        """
        self._is_with_priority = is_with_priority

    @property
    def is_support_colonless_ident(self):
        """
        Gets the is_support_colonless_ident of this UnifiedAgentSyslogParser.

        :return: The is_support_colonless_ident of this UnifiedAgentSyslogParser.
        :rtype: bool
        """
        return self._is_support_colonless_ident

    @is_support_colonless_ident.setter
    def is_support_colonless_ident(self, is_support_colonless_ident):
        """
        Sets the is_support_colonless_ident of this UnifiedAgentSyslogParser.

        :param is_support_colonless_ident: The is_support_colonless_ident of this UnifiedAgentSyslogParser.
        :type: bool
        """
        self._is_support_colonless_ident = is_support_colonless_ident

    @property
    def syslog_parser_type(self):
        """
        Gets the syslog_parser_type of this UnifiedAgentSyslogParser.
        Allowed values for this property are: "STRING", "REGEXP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The syslog_parser_type of this UnifiedAgentSyslogParser.
        :rtype: str
        """
        return self._syslog_parser_type

    @syslog_parser_type.setter
    def syslog_parser_type(self, syslog_parser_type):
        """
        Sets the syslog_parser_type of this UnifiedAgentSyslogParser.

        :param syslog_parser_type: The syslog_parser_type of this UnifiedAgentSyslogParser.
        :type: str
        """
        allowed_values = ["STRING", "REGEXP"]
        if not value_allowed_none_or_none_sentinel(syslog_parser_type, allowed_values):
            syslog_parser_type = 'UNKNOWN_ENUM_VALUE'
        self._syslog_parser_type = syslog_parser_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateSSLCipherSuiteDetails(object):
    """
    The configuration details of an SSL cipher suite.

    The algorithms that compose a cipher suite help you secure Transport Layer Security (TLS) or Secure Socket Layer
    (SSL) network connections. A cipher suite defines the list of security algorithms your load balancer uses to
    negotiate with peers while sending and receiving information. The cipher suites you use affect the security
    level, performance, and compatibility of your data traffic.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.

    Oracle created the following predefined cipher suites that you can specify when you define a resource's
    `SSL configuration`__. You can `create custom
    cipher suites`__ if the predefined cipher
    suites do not meet your requirements.


    *  __oci-default-ssl-cipher-suite-v1__

    \"DHE-RSA-AES128-GCM-SHA256\"
    \"DHE-RSA-AES128-SHA256\"
    \"DHE-RSA-AES256-GCM-SHA384\"
    \"DHE-RSA-AES256-SHA256\"
    \"ECDHE-RSA-AES128-GCM-SHA256\"
    \"ECDHE-RSA-AES128-SHA256\"
    \"ECDHE-RSA-AES256-GCM-SHA384\"
    \"ECDHE-RSA-AES256-SHA384\"

    *  __oci-modern-ssl-cipher-suite-v1__

    \"AES128-GCM-SHA256\"
    \"AES128-SHA256\"
    \"AES256-GCM-SHA384\"
    \"AES256-SHA256\"
    \"DHE-RSA-AES128-GCM-SHA256\"
    \"DHE-RSA-AES128-SHA256\"
    \"DHE-RSA-AES256-GCM-SHA384\"
    \"DHE-RSA-AES256-SHA256\"
    \"ECDHE-ECDSA-AES128-GCM-SHA256\"
    \"ECDHE-ECDSA-AES128-SHA256\"
    \"ECDHE-ECDSA-AES256-GCM-SHA384\"
    \"ECDHE-ECDSA-AES256-SHA384\"
    \"ECDHE-RSA-AES128-GCM-SHA256\"
    \"ECDHE-RSA-AES128-SHA256\"
    \"ECDHE-RSA-AES256-GCM-SHA384\"
    \"ECDHE-RSA-AES256-SHA384\"

    *  __oci-compatible-ssl-cipher-suite-v1__

    \"AES128-GCM-SHA256\"
    \"AES128-SHA\"
    \"AES128-SHA256\"
    \"AES256-GCM-SHA384\"
    \"AES256-SHA\"
    \"AES256-SHA256\"
    \"DHE-RSA-AES128-GCM-SHA256\"
    \"DHE-RSA-AES128-SHA256\"
    \"DHE-RSA-AES256-GCM-SHA384\"
    \"DHE-RSA-AES256-SHA256\"
    \"ECDHE-ECDSA-AES128-GCM-SHA256\"
    \"ECDHE-ECDSA-AES128-SHA\"
    \"ECDHE-ECDSA-AES128-SHA256\"
    \"ECDHE-ECDSA-AES256-GCM-SHA384\"
    \"ECDHE-ECDSA-AES256-SHA\"
    \"ECDHE-ECDSA-AES256-SHA384\"
    \"ECDHE-RSA-AES128-GCM-SHA256\"
    \"ECDHE-RSA-AES128-SHA\"
    \"ECDHE-RSA-AES128-SHA256\"
    \"ECDHE-RSA-AES256-GCM-SHA384\"
    \"ECDHE-RSA-AES256-SHA\"
    \"ECDHE-RSA-AES256-SHA384\"

    *  __oci-wider-compatible-ssl-cipher-suite-v1__

    \"AES128-GCM-SHA256\"
    \"AES128-SHA\"
    \"AES128-SHA256\"
    \"AES256-GCM-SHA384\"
    \"AES256-SHA\"
    \"AES256-SHA256\"
    \"CAMELLIA128-SHA\"
    \"CAMELLIA256-SHA\"
    \"DES-CBC3-SHA\"
    \"DH-DSS-AES128-GCM-SHA256\"
    \"DH-DSS-AES128-SHA\"
    \"DH-DSS-AES128-SHA256\"
    \"DH-DSS-AES256-GCM-SHA384\"
    \"DH-DSS-AES256-SHA\"
    \"DH-DSS-AES256-SHA256\"
    \"DH-DSS-CAMELLIA128-SHA\"
    \"DH-DSS-CAMELLIA256-SHA\"
    \"DH-DSS-DES-CBC3-SHAv\"
    \"DH-DSS-SEED-SHA\"
    \"DH-RSA-AES128-GCM-SHA256\"
    \"DH-RSA-AES128-SHA\"
    \"DH-RSA-AES128-SHA256\"
    \"DH-RSA-AES256-GCM-SHA384\"
    \"DH-RSA-AES256-SHA\"
    \"DH-RSA-AES256-SHA256\"
    \"DH-RSA-CAMELLIA128-SHA\"
    \"DH-RSA-CAMELLIA256-SHA\"
    \"DH-RSA-DES-CBC3-SHA\"
    \"DH-RSA-SEED-SHA\"
    \"DHE-DSS-AES128-GCM-SHA256\"
    \"DHE-DSS-AES128-SHA\"
    \"DHE-DSS-AES128-SHA256\"
    \"DHE-DSS-AES256-GCM-SHA384\"
    \"DHE-DSS-AES256-SHA\"
    \"DHE-DSS-AES256-SHA256\"
    \"DHE-DSS-CAMELLIA128-SHA\"
    \"DHE-DSS-CAMELLIA256-SHA\"
    \"DHE-DSS-DES-CBC3-SHA\"
    \"DHE-DSS-SEED-SHA\"
    \"DHE-RSA-AES128-GCM-SHA256\"
    \"DHE-RSA-AES128-SHA\"
    \"DHE-RSA-AES128-SHA256\"
    \"DHE-RSA-AES256-GCM-SHA384\"
    \"DHE-RSA-AES256-SHA\"
    \"DHE-RSA-AES256-SHA256\"
    \"DHE-RSA-CAMELLIA128-SHA\"
    \"DHE-RSA-CAMELLIA256-SHA\"
    \"DHE-RSA-DES-CBC3-SHA\"
    \"DHE-RSA-SEED-SHA\"
    \"ECDH-ECDSA-AES128-GCM-SHA256\"
    \"ECDH-ECDSA-AES128-SHA\"
    \"ECDH-ECDSA-AES128-SHA256\"
    \"ECDH-ECDSA-AES256-GCM-SHA384\"
    \"ECDH-ECDSA-AES256-SHA\"
    \"ECDH-ECDSA-AES256-SHA384\"
    \"ECDH-ECDSA-DES-CBC3-SHA\"
    \"ECDH-ECDSA-RC4-SHA\"
    \"ECDH-RSA-AES128-GCM-SHA256\"
    \"ECDH-RSA-AES128-SHA\"
    \"ECDH-RSA-AES128-SHA256\"
    \"ECDH-RSA-AES256-GCM-SHA384\"
    \"ECDH-RSA-AES256-SHA\"
    \"ECDH-RSA-AES256-SHA384\"
    \"ECDH-RSA-DES-CBC3-SHA\"
    \"ECDH-RSA-RC4-SHA\"
    \"ECDHE-ECDSA-AES128-GCM-SHA256\"
    \"ECDHE-ECDSA-AES128-SHA\"
    \"ECDHE-ECDSA-AES128-SHA256\"
    \"ECDHE-ECDSA-AES256-GCM-SHA384\"
    \"ECDHE-ECDSA-AES256-SHA\"
    \"ECDHE-ECDSA-AES256-SHA384\"
    \"ECDHE-ECDSA-DES-CBC3-SHA\"
    \"ECDHE-ECDSA-RC4-SHA\"
    \"ECDHE-RSA-AES128-GCM-SHA256\"
    \"ECDHE-RSA-AES128-SHA\"
    \"ECDHE-RSA-AES128-SHA256\"
    \"ECDHE-RSA-AES256-GCM-SHA384\"
    \"ECDHE-RSA-AES256-SHA\"
    \"ECDHE-RSA-AES256-SHA384\"
    \"ECDHE-RSA-DES-CBC3-SHA\"
    \"ECDHE-RSA-RC4-SHA\"
    \"IDEA-CBC-SHA\"
    \"KRB5-DES-CBC3-MD5\"
    \"KRB5-DES-CBC3-SHA\"
    \"KRB5-IDEA-CBC-MD5\"
    \"KRB5-IDEA-CBC-SHA\"
    \"KRB5-RC4-MD5\"
    \"KRB5-RC4-SHA\"
    \"PSK-3DES-EDE-CBC-SHA\"
    \"PSK-AES128-CBC-SHA\"
    \"PSK-AES256-CBC-SHA\"
    \"PSK-RC4-SHA\"
    \"RC4-MD5\"
    \"RC4-SHA\"
    \"SEED-SHA\"

    __ https://docs.cloud.oracle.com/api/#/en/loadbalancer/20170115/datatypes/SSLConfigurationDetails
    __ https://docs.cloud.oracle.com/api/#/en/loadbalancer/20170115/SSLCipherSuite/CreateSSLCipherSuite
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateSSLCipherSuiteDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this CreateSSLCipherSuiteDetails.
        :type name: str

        :param ciphers:
            The value to assign to the ciphers property of this CreateSSLCipherSuiteDetails.
        :type ciphers: list[str]

        """
        self.swagger_types = {
            'name': 'str',
            'ciphers': 'list[str]'
        }

        self.attribute_map = {
            'name': 'name',
            'ciphers': 'ciphers'
        }

        self._name = None
        self._ciphers = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateSSLCipherSuiteDetails.
        A friendly name for the SSL cipher suite. It must be unique and it cannot be changed.

        **Note:** The name of your user-defined cipher suite must not be the same as any of Oracle's predefined or
                  reserved SSL cipher suite names:

        * oci-default-ssl-cipher-suite-v1
        * oci-modern-ssl-cipher-suite-v1
        * oci-compatible-ssl-cipher-suite-v1
        * oci-wider-compatible-ssl-cipher-suite-v1
        * oci-customized-ssl-cipher-suite

        example: `example_cipher_suite`


        :return: The name of this CreateSSLCipherSuiteDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateSSLCipherSuiteDetails.
        A friendly name for the SSL cipher suite. It must be unique and it cannot be changed.

        **Note:** The name of your user-defined cipher suite must not be the same as any of Oracle's predefined or
                  reserved SSL cipher suite names:

        * oci-default-ssl-cipher-suite-v1
        * oci-modern-ssl-cipher-suite-v1
        * oci-compatible-ssl-cipher-suite-v1
        * oci-wider-compatible-ssl-cipher-suite-v1
        * oci-customized-ssl-cipher-suite

        example: `example_cipher_suite`


        :param name: The name of this CreateSSLCipherSuiteDetails.
        :type: str
        """
        self._name = name

    @property
    def ciphers(self):
        """
        **[Required]** Gets the ciphers of this CreateSSLCipherSuiteDetails.
        A list of SSL ciphers the load balancer must support for HTTPS or SSL connections.

        The following ciphers are valid values for this property:

        *  __TLSv1.2 ciphers__

                \"AES128-GCM-SHA256\"
                \"AES128-SHA256\"
                \"AES256-GCM-SHA384\"
                \"AES256-SHA256\"
                \"DH-DSS-AES128-GCM-SHA256\"
                \"DH-DSS-AES128-SHA256\"
                \"DH-DSS-AES256-GCM-SHA384\"
                \"DH-DSS-AES256-SHA256\"
                \"DH-RSA-AES128-GCM-SHA256\"
                \"DH-RSA-AES128-SHA256\"
                \"DH-RSA-AES256-GCM-SHA384\"
                \"DH-RSA-AES256-SHA256\"
                \"DHE-DSS-AES128-GCM-SHA256\"
                \"DHE-DSS-AES128-SHA256\"
                \"DHE-DSS-AES256-GCM-SHA384\"
                \"DHE-DSS-AES256-SHA256\"
                \"DHE-RSA-AES128-GCM-SHA256\"
                \"DHE-RSA-AES128-SHA256\"
                \"DHE-RSA-AES256-GCM-SHA384\"
                \"DHE-RSA-AES256-SHA256\"
                \"ECDH-ECDSA-AES128-GCM-SHA256\"
                \"ECDH-ECDSA-AES128-SHA256\"
                \"ECDH-ECDSA-AES256-GCM-SHA384\"
                \"ECDH-ECDSA-AES256-SHA384\"
                \"ECDH-RSA-AES128-GCM-SHA256\"
                \"ECDH-RSA-AES128-SHA256\"
                \"ECDH-RSA-AES256-GCM-SHA384\"
                \"ECDH-RSA-AES256-SHA384\"
                \"ECDHE-ECDSA-AES128-GCM-SHA256\"
                \"ECDHE-ECDSA-AES128-SHA256\"
                \"ECDHE-ECDSA-AES256-GCM-SHA384\"
                \"ECDHE-ECDSA-AES256-SHA384\"
                \"ECDHE-RSA-AES128-GCM-SHA256\"
                \"ECDHE-RSA-AES128-SHA256\"
                \"ECDHE-RSA-AES256-GCM-SHA384\"
                \"ECDHE-RSA-AES256-SHA384\"

        *  __TLSv1 ciphers also supported by TLSv1.2__

                \"AES128-SHA\"
                \"AES256-SHA\"
                \"CAMELLIA128-SHA\"
                \"CAMELLIA256-SHA\"
                \"DES-CBC3-SHA\"
                \"DH-DSS-AES128-SHA\"
                \"DH-DSS-AES256-SHA\"
                \"DH-DSS-CAMELLIA128-SHA\"
                \"DH-DSS-CAMELLIA256-SHA\"
                \"DH-DSS-DES-CBC3-SHAv\"
                \"DH-DSS-SEED-SHA\"
                \"DH-RSA-AES128-SHA\"
                \"DH-RSA-AES256-SHA\"
                \"DH-RSA-CAMELLIA128-SHA\"
                \"DH-RSA-CAMELLIA256-SHA\"
                \"DH-RSA-DES-CBC3-SHA\"
                \"DH-RSA-SEED-SHA\"
                \"DHE-DSS-AES128-SHA\"
                \"DHE-DSS-AES256-SHA\"
                \"DHE-DSS-CAMELLIA128-SHA\"
                \"DHE-DSS-CAMELLIA256-SHA\"
                \"DHE-DSS-DES-CBC3-SHA\"
                \"DHE-DSS-SEED-SHA\"
                \"DHE-RSA-AES128-SHA\"
                \"DHE-RSA-AES256-SHA\"
                \"DHE-RSA-CAMELLIA128-SHA\"
                \"DHE-RSA-CAMELLIA256-SHA\"
                \"DHE-RSA-DES-CBC3-SHA\"
                \"DHE-RSA-SEED-SHA\"
                \"ECDH-ECDSA-AES128-SHA\"
                \"ECDH-ECDSA-AES256-SHA\"
                \"ECDH-ECDSA-DES-CBC3-SHA\"
                \"ECDH-ECDSA-RC4-SHA\"
                \"ECDH-RSA-AES128-SHA\"
                \"ECDH-RSA-AES256-SHA\"
                \"ECDH-RSA-DES-CBC3-SHA\"
                \"ECDH-RSA-RC4-SHA\"
                \"ECDHE-ECDSA-AES128-SHA\"
                \"ECDHE-ECDSA-AES256-SHA\"
                \"ECDHE-ECDSA-DES-CBC3-SHA\"
                \"ECDHE-ECDSA-RC4-SHA\"
                \"ECDHE-RSA-AES128-SHA\"
                \"ECDHE-RSA-AES256-SHA\"
                \"ECDHE-RSA-DES-CBC3-SHA\"
                \"ECDHE-RSA-RC4-SHA\"
                \"IDEA-CBC-SHA\"
                \"KRB5-DES-CBC3-MD5\"
                \"KRB5-DES-CBC3-SHA\"
                \"KRB5-IDEA-CBC-MD5\"
                \"KRB5-IDEA-CBC-SHA\"
                \"KRB5-RC4-MD5\"
                \"KRB5-RC4-SHA\"
                \"PSK-3DES-EDE-CBC-SHA\"
                \"PSK-AES128-CBC-SHA\"
                \"PSK-AES256-CBC-SHA\"
                \"PSK-RC4-SHA\"
                \"RC4-MD5\"
                \"RC4-SHA\"
                \"SEED-SHA\"

        example: `[\"ECDHE-RSA-AES256-GCM-SHA384\",\"ECDHE-ECDSA-AES256-GCM-SHA384\",\"ECDHE-RSA-AES128-GCM-SHA256\"]`


        :return: The ciphers of this CreateSSLCipherSuiteDetails.
        :rtype: list[str]
        """
        return self._ciphers

    @ciphers.setter
    def ciphers(self, ciphers):
        """
        Sets the ciphers of this CreateSSLCipherSuiteDetails.
        A list of SSL ciphers the load balancer must support for HTTPS or SSL connections.

        The following ciphers are valid values for this property:

        *  __TLSv1.2 ciphers__

                \"AES128-GCM-SHA256\"
                \"AES128-SHA256\"
                \"AES256-GCM-SHA384\"
                \"AES256-SHA256\"
                \"DH-DSS-AES128-GCM-SHA256\"
                \"DH-DSS-AES128-SHA256\"
                \"DH-DSS-AES256-GCM-SHA384\"
                \"DH-DSS-AES256-SHA256\"
                \"DH-RSA-AES128-GCM-SHA256\"
                \"DH-RSA-AES128-SHA256\"
                \"DH-RSA-AES256-GCM-SHA384\"
                \"DH-RSA-AES256-SHA256\"
                \"DHE-DSS-AES128-GCM-SHA256\"
                \"DHE-DSS-AES128-SHA256\"
                \"DHE-DSS-AES256-GCM-SHA384\"
                \"DHE-DSS-AES256-SHA256\"
                \"DHE-RSA-AES128-GCM-SHA256\"
                \"DHE-RSA-AES128-SHA256\"
                \"DHE-RSA-AES256-GCM-SHA384\"
                \"DHE-RSA-AES256-SHA256\"
                \"ECDH-ECDSA-AES128-GCM-SHA256\"
                \"ECDH-ECDSA-AES128-SHA256\"
                \"ECDH-ECDSA-AES256-GCM-SHA384\"
                \"ECDH-ECDSA-AES256-SHA384\"
                \"ECDH-RSA-AES128-GCM-SHA256\"
                \"ECDH-RSA-AES128-SHA256\"
                \"ECDH-RSA-AES256-GCM-SHA384\"
                \"ECDH-RSA-AES256-SHA384\"
                \"ECDHE-ECDSA-AES128-GCM-SHA256\"
                \"ECDHE-ECDSA-AES128-SHA256\"
                \"ECDHE-ECDSA-AES256-GCM-SHA384\"
                \"ECDHE-ECDSA-AES256-SHA384\"
                \"ECDHE-RSA-AES128-GCM-SHA256\"
                \"ECDHE-RSA-AES128-SHA256\"
                \"ECDHE-RSA-AES256-GCM-SHA384\"
                \"ECDHE-RSA-AES256-SHA384\"

        *  __TLSv1 ciphers also supported by TLSv1.2__

                \"AES128-SHA\"
                \"AES256-SHA\"
                \"CAMELLIA128-SHA\"
                \"CAMELLIA256-SHA\"
                \"DES-CBC3-SHA\"
                \"DH-DSS-AES128-SHA\"
                \"DH-DSS-AES256-SHA\"
                \"DH-DSS-CAMELLIA128-SHA\"
                \"DH-DSS-CAMELLIA256-SHA\"
                \"DH-DSS-DES-CBC3-SHAv\"
                \"DH-DSS-SEED-SHA\"
                \"DH-RSA-AES128-SHA\"
                \"DH-RSA-AES256-SHA\"
                \"DH-RSA-CAMELLIA128-SHA\"
                \"DH-RSA-CAMELLIA256-SHA\"
                \"DH-RSA-DES-CBC3-SHA\"
                \"DH-RSA-SEED-SHA\"
                \"DHE-DSS-AES128-SHA\"
                \"DHE-DSS-AES256-SHA\"
                \"DHE-DSS-CAMELLIA128-SHA\"
                \"DHE-DSS-CAMELLIA256-SHA\"
                \"DHE-DSS-DES-CBC3-SHA\"
                \"DHE-DSS-SEED-SHA\"
                \"DHE-RSA-AES128-SHA\"
                \"DHE-RSA-AES256-SHA\"
                \"DHE-RSA-CAMELLIA128-SHA\"
                \"DHE-RSA-CAMELLIA256-SHA\"
                \"DHE-RSA-DES-CBC3-SHA\"
                \"DHE-RSA-SEED-SHA\"
                \"ECDH-ECDSA-AES128-SHA\"
                \"ECDH-ECDSA-AES256-SHA\"
                \"ECDH-ECDSA-DES-CBC3-SHA\"
                \"ECDH-ECDSA-RC4-SHA\"
                \"ECDH-RSA-AES128-SHA\"
                \"ECDH-RSA-AES256-SHA\"
                \"ECDH-RSA-DES-CBC3-SHA\"
                \"ECDH-RSA-RC4-SHA\"
                \"ECDHE-ECDSA-AES128-SHA\"
                \"ECDHE-ECDSA-AES256-SHA\"
                \"ECDHE-ECDSA-DES-CBC3-SHA\"
                \"ECDHE-ECDSA-RC4-SHA\"
                \"ECDHE-RSA-AES128-SHA\"
                \"ECDHE-RSA-AES256-SHA\"
                \"ECDHE-RSA-DES-CBC3-SHA\"
                \"ECDHE-RSA-RC4-SHA\"
                \"IDEA-CBC-SHA\"
                \"KRB5-DES-CBC3-MD5\"
                \"KRB5-DES-CBC3-SHA\"
                \"KRB5-IDEA-CBC-MD5\"
                \"KRB5-IDEA-CBC-SHA\"
                \"KRB5-RC4-MD5\"
                \"KRB5-RC4-SHA\"
                \"PSK-3DES-EDE-CBC-SHA\"
                \"PSK-AES128-CBC-SHA\"
                \"PSK-AES256-CBC-SHA\"
                \"PSK-RC4-SHA\"
                \"RC4-MD5\"
                \"RC4-SHA\"
                \"SEED-SHA\"

        example: `[\"ECDHE-RSA-AES256-GCM-SHA384\",\"ECDHE-ECDSA-AES256-GCM-SHA384\",\"ECDHE-RSA-AES128-GCM-SHA256\"]`


        :param ciphers: The ciphers of this CreateSSLCipherSuiteDetails.
        :type: list[str]
        """
        self._ciphers = ciphers

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TimeRange(object):
    """
    Specify time range. This paramter can be overwritten if time criteria is specified in the query string. If no time criteria are found in query string this time range is used.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TimeRange object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_start:
            The value to assign to the time_start property of this TimeRange.
        :type time_start: datetime

        :param time_end:
            The value to assign to the time_end property of this TimeRange.
        :type time_end: datetime

        :param time_zone:
            The value to assign to the time_zone property of this TimeRange.
        :type time_zone: str

        """
        self.swagger_types = {
            'time_start': 'datetime',
            'time_end': 'datetime',
            'time_zone': 'str'
        }

        self.attribute_map = {
            'time_start': 'timeStart',
            'time_end': 'timeEnd',
            'time_zone': 'timeZone'
        }

        self._time_start = None
        self._time_end = None
        self._time_zone = None

    @property
    def time_start(self):
        """
        **[Required]** Gets the time_start of this TimeRange.
        Time for query to start matching results from. Start time must be less than end time otherwise it will result in error.


        :return: The time_start of this TimeRange.
        :rtype: datetime
        """
        return self._time_start

    @time_start.setter
    def time_start(self, time_start):
        """
        Sets the time_start of this TimeRange.
        Time for query to start matching results from. Start time must be less than end time otherwise it will result in error.


        :param time_start: The time_start of this TimeRange.
        :type: datetime
        """
        self._time_start = time_start

    @property
    def time_end(self):
        """
        **[Required]** Gets the time_end of this TimeRange.
        Time for query to stop matching results to. End Time must be greater than or equal to start time otherwise it will result in error.


        :return: The time_end of this TimeRange.
        :rtype: datetime
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this TimeRange.
        Time for query to stop matching results to. End Time must be greater than or equal to start time otherwise it will result in error.


        :param time_end: The time_end of this TimeRange.
        :type: datetime
        """
        self._time_end = time_end

    @property
    def time_zone(self):
        """
        Gets the time_zone of this TimeRange.
        Time zone for query.


        :return: The time_zone of this TimeRange.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this TimeRange.
        Time zone for query.


        :param time_zone: The time_zone of this TimeRange.
        :type: str
        """
        self._time_zone = time_zone

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ReplicaDetails(object):
    """
    Number of replicas of service components like Rest Proxy, CA and Console
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ReplicaDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param proxy_count:
            The value to assign to the proxy_count property of this ReplicaDetails.
        :type proxy_count: int

        :param ca_count:
            The value to assign to the ca_count property of this ReplicaDetails.
        :type ca_count: int

        :param console_count:
            The value to assign to the console_count property of this ReplicaDetails.
        :type console_count: int

        """
        self.swagger_types = {
            'proxy_count': 'int',
            'ca_count': 'int',
            'console_count': 'int'
        }

        self.attribute_map = {
            'proxy_count': 'proxyCount',
            'ca_count': 'caCount',
            'console_count': 'consoleCount'
        }

        self._proxy_count = None
        self._ca_count = None
        self._console_count = None

    @property
    def proxy_count(self):
        """
        Gets the proxy_count of this ReplicaDetails.
        Number of REST proxy replicas


        :return: The proxy_count of this ReplicaDetails.
        :rtype: int
        """
        return self._proxy_count

    @proxy_count.setter
    def proxy_count(self, proxy_count):
        """
        Sets the proxy_count of this ReplicaDetails.
        Number of REST proxy replicas


        :param proxy_count: The proxy_count of this ReplicaDetails.
        :type: int
        """
        self._proxy_count = proxy_count

    @property
    def ca_count(self):
        """
        Gets the ca_count of this ReplicaDetails.
        Number of CA replicas


        :return: The ca_count of this ReplicaDetails.
        :rtype: int
        """
        return self._ca_count

    @ca_count.setter
    def ca_count(self, ca_count):
        """
        Sets the ca_count of this ReplicaDetails.
        Number of CA replicas


        :param ca_count: The ca_count of this ReplicaDetails.
        :type: int
        """
        self._ca_count = ca_count

    @property
    def console_count(self):
        """
        Gets the console_count of this ReplicaDetails.
        Number of console replicas


        :return: The console_count of this ReplicaDetails.
        :rtype: int
        """
        return self._console_count

    @console_count.setter
    def console_count(self, console_count):
        """
        Sets the console_count of this ReplicaDetails.
        Number of console replicas


        :param console_count: The console_count of this ReplicaDetails.
        :type: int
        """
        self._console_count = console_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RecommendationSummary(object):
    """
    Recommendation Definition.
    """

    #: A constant which can be used with the type property of a RecommendationSummary.
    #: This constant has a value of "DETECTOR_PROBLEMS"
    TYPE_DETECTOR_PROBLEMS = "DETECTOR_PROBLEMS"

    #: A constant which can be used with the type property of a RecommendationSummary.
    #: This constant has a value of "RESOLVED_PROBLEMS"
    TYPE_RESOLVED_PROBLEMS = "RESOLVED_PROBLEMS"

    #: A constant which can be used with the risk_level property of a RecommendationSummary.
    #: This constant has a value of "CRITICAL"
    RISK_LEVEL_CRITICAL = "CRITICAL"

    #: A constant which can be used with the risk_level property of a RecommendationSummary.
    #: This constant has a value of "HIGH"
    RISK_LEVEL_HIGH = "HIGH"

    #: A constant which can be used with the risk_level property of a RecommendationSummary.
    #: This constant has a value of "MEDIUM"
    RISK_LEVEL_MEDIUM = "MEDIUM"

    #: A constant which can be used with the risk_level property of a RecommendationSummary.
    #: This constant has a value of "LOW"
    RISK_LEVEL_LOW = "LOW"

    #: A constant which can be used with the risk_level property of a RecommendationSummary.
    #: This constant has a value of "MINOR"
    RISK_LEVEL_MINOR = "MINOR"

    #: A constant which can be used with the lifecycle_state property of a RecommendationSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a RecommendationSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a RecommendationSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a RecommendationSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a RecommendationSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a RecommendationSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a RecommendationSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_detail property of a RecommendationSummary.
    #: This constant has a value of "OPEN"
    LIFECYCLE_DETAIL_OPEN = "OPEN"

    #: A constant which can be used with the lifecycle_detail property of a RecommendationSummary.
    #: This constant has a value of "RESOLVED"
    LIFECYCLE_DETAIL_RESOLVED = "RESOLVED"

    #: A constant which can be used with the lifecycle_detail property of a RecommendationSummary.
    #: This constant has a value of "DISMISSED"
    LIFECYCLE_DETAIL_DISMISSED = "DISMISSED"

    def __init__(self, **kwargs):
        """
        Initializes a new RecommendationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this RecommendationSummary.
        :type id: str

        :param type:
            The value to assign to the type property of this RecommendationSummary.
            Allowed values for this property are: "DETECTOR_PROBLEMS", "RESOLVED_PROBLEMS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param tenant_id:
            The value to assign to the tenant_id property of this RecommendationSummary.
        :type tenant_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this RecommendationSummary.
        :type compartment_id: str

        :param target_id:
            The value to assign to the target_id property of this RecommendationSummary.
        :type target_id: str

        :param details:
            The value to assign to the details property of this RecommendationSummary.
        :type details: dict(str, str)

        :param risk_level:
            The value to assign to the risk_level property of this RecommendationSummary.
            Allowed values for this property are: "CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type risk_level: str

        :param problem_count:
            The value to assign to the problem_count property of this RecommendationSummary.
        :type problem_count: int

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this RecommendationSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_detail:
            The value to assign to the lifecycle_detail property of this RecommendationSummary.
            Allowed values for this property are: "OPEN", "RESOLVED", "DISMISSED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_detail: str

        :param time_created:
            The value to assign to the time_created property of this RecommendationSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this RecommendationSummary.
        :type time_updated: datetime

        :param name:
            The value to assign to the name property of this RecommendationSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this RecommendationSummary.
        :type description: str

        """
        self.swagger_types = {
            'id': 'str',
            'type': 'str',
            'tenant_id': 'str',
            'compartment_id': 'str',
            'target_id': 'str',
            'details': 'dict(str, str)',
            'risk_level': 'str',
            'problem_count': 'int',
            'lifecycle_state': 'str',
            'lifecycle_detail': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'name': 'str',
            'description': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'type': 'type',
            'tenant_id': 'tenantId',
            'compartment_id': 'compartmentId',
            'target_id': 'targetId',
            'details': 'details',
            'risk_level': 'riskLevel',
            'problem_count': 'problemCount',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_detail': 'lifecycleDetail',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'name': 'name',
            'description': 'description'
        }

        self._id = None
        self._type = None
        self._tenant_id = None
        self._compartment_id = None
        self._target_id = None
        self._details = None
        self._risk_level = None
        self._problem_count = None
        self._lifecycle_state = None
        self._lifecycle_detail = None
        self._time_created = None
        self._time_updated = None
        self._name = None
        self._description = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this RecommendationSummary.
        Unique identifier for Recommendation


        :return: The id of this RecommendationSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RecommendationSummary.
        Unique identifier for Recommendation


        :param id: The id of this RecommendationSummary.
        :type: str
        """
        self._id = id

    @property
    def type(self):
        """
        Gets the type of this RecommendationSummary.
        Recommendation type

        Allowed values for this property are: "DETECTOR_PROBLEMS", "RESOLVED_PROBLEMS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this RecommendationSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this RecommendationSummary.
        Recommendation type


        :param type: The type of this RecommendationSummary.
        :type: str
        """
        allowed_values = ["DETECTOR_PROBLEMS", "RESOLVED_PROBLEMS"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def tenant_id(self):
        """
        Gets the tenant_id of this RecommendationSummary.
        Tenant Identifier


        :return: The tenant_id of this RecommendationSummary.
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """
        Sets the tenant_id of this RecommendationSummary.
        Tenant Identifier


        :param tenant_id: The tenant_id of this RecommendationSummary.
        :type: str
        """
        self._tenant_id = tenant_id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this RecommendationSummary.
        Compartment Identifier


        :return: The compartment_id of this RecommendationSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this RecommendationSummary.
        Compartment Identifier


        :param compartment_id: The compartment_id of this RecommendationSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def target_id(self):
        """
        **[Required]** Gets the target_id of this RecommendationSummary.
        targetId associated with the problem


        :return: The target_id of this RecommendationSummary.
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """
        Sets the target_id of this RecommendationSummary.
        targetId associated with the problem


        :param target_id: The target_id of this RecommendationSummary.
        :type: str
        """
        self._target_id = target_id

    @property
    def details(self):
        """
        **[Required]** Gets the details of this RecommendationSummary.
        Recommendation details


        :return: The details of this RecommendationSummary.
        :rtype: dict(str, str)
        """
        return self._details

    @details.setter
    def details(self, details):
        """
        Sets the details of this RecommendationSummary.
        Recommendation details


        :param details: The details of this RecommendationSummary.
        :type: dict(str, str)
        """
        self._details = details

    @property
    def risk_level(self):
        """
        Gets the risk_level of this RecommendationSummary.
        The Risk Level

        Allowed values for this property are: "CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The risk_level of this RecommendationSummary.
        :rtype: str
        """
        return self._risk_level

    @risk_level.setter
    def risk_level(self, risk_level):
        """
        Sets the risk_level of this RecommendationSummary.
        The Risk Level


        :param risk_level: The risk_level of this RecommendationSummary.
        :type: str
        """
        allowed_values = ["CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR"]
        if not value_allowed_none_or_none_sentinel(risk_level, allowed_values):
            risk_level = 'UNKNOWN_ENUM_VALUE'
        self._risk_level = risk_level

    @property
    def problem_count(self):
        """
        **[Required]** Gets the problem_count of this RecommendationSummary.
        Count number of the problem


        :return: The problem_count of this RecommendationSummary.
        :rtype: int
        """
        return self._problem_count

    @problem_count.setter
    def problem_count(self, problem_count):
        """
        Sets the problem_count of this RecommendationSummary.
        Count number of the problem


        :param problem_count: The problem_count of this RecommendationSummary.
        :type: int
        """
        self._problem_count = problem_count

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this RecommendationSummary.
        The current state of the Recommendation.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this RecommendationSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this RecommendationSummary.
        The current state of the Recommendation.


        :param lifecycle_state: The lifecycle_state of this RecommendationSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_detail(self):
        """
        **[Required]** Gets the lifecycle_detail of this RecommendationSummary.
        The lifecycleDetail will give more detail on the substate of the lifecycleState.

        Allowed values for this property are: "OPEN", "RESOLVED", "DISMISSED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_detail of this RecommendationSummary.
        :rtype: str
        """
        return self._lifecycle_detail

    @lifecycle_detail.setter
    def lifecycle_detail(self, lifecycle_detail):
        """
        Sets the lifecycle_detail of this RecommendationSummary.
        The lifecycleDetail will give more detail on the substate of the lifecycleState.


        :param lifecycle_detail: The lifecycle_detail of this RecommendationSummary.
        :type: str
        """
        allowed_values = ["OPEN", "RESOLVED", "DISMISSED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_detail, allowed_values):
            lifecycle_detail = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_detail = lifecycle_detail

    @property
    def time_created(self):
        """
        Gets the time_created of this RecommendationSummary.
        problem creating time


        :return: The time_created of this RecommendationSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this RecommendationSummary.
        problem creating time


        :param time_created: The time_created of this RecommendationSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this RecommendationSummary.
        problem updating time


        :return: The time_updated of this RecommendationSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this RecommendationSummary.
        problem updating time


        :param time_updated: The time_updated of this RecommendationSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def name(self):
        """
        **[Required]** Gets the name of this RecommendationSummary.
        recommendation string showing on UX


        :return: The name of this RecommendationSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this RecommendationSummary.
        recommendation string showing on UX


        :param name: The name of this RecommendationSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        **[Required]** Gets the description of this RecommendationSummary.
        description of the recommendation


        :return: The description of this RecommendationSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this RecommendationSummary.
        description of the recommendation


        :param description: The description of this RecommendationSummary.
        :type: str
        """
        self._description = description

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Run(object):
    """
    A run object.
    """

    #: A constant which can be used with the language property of a Run.
    #: This constant has a value of "SCALA"
    LANGUAGE_SCALA = "SCALA"

    #: A constant which can be used with the language property of a Run.
    #: This constant has a value of "JAVA"
    LANGUAGE_JAVA = "JAVA"

    #: A constant which can be used with the language property of a Run.
    #: This constant has a value of "PYTHON"
    LANGUAGE_PYTHON = "PYTHON"

    #: A constant which can be used with the language property of a Run.
    #: This constant has a value of "SQL"
    LANGUAGE_SQL = "SQL"

    #: A constant which can be used with the lifecycle_state property of a Run.
    #: This constant has a value of "ACCEPTED"
    LIFECYCLE_STATE_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the lifecycle_state property of a Run.
    #: This constant has a value of "IN_PROGRESS"
    LIFECYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a Run.
    #: This constant has a value of "CANCELING"
    LIFECYCLE_STATE_CANCELING = "CANCELING"

    #: A constant which can be used with the lifecycle_state property of a Run.
    #: This constant has a value of "CANCELED"
    LIFECYCLE_STATE_CANCELED = "CANCELED"

    #: A constant which can be used with the lifecycle_state property of a Run.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a Run.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    def __init__(self, **kwargs):
        """
        Initializes a new Run object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param archive_uri:
            The value to assign to the archive_uri property of this Run.
        :type archive_uri: str

        :param arguments:
            The value to assign to the arguments property of this Run.
        :type arguments: list[str]

        :param application_id:
            The value to assign to the application_id property of this Run.
        :type application_id: str

        :param class_name:
            The value to assign to the class_name property of this Run.
        :type class_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Run.
        :type compartment_id: str

        :param configuration:
            The value to assign to the configuration property of this Run.
        :type configuration: dict(str, str)

        :param data_read_in_bytes:
            The value to assign to the data_read_in_bytes property of this Run.
        :type data_read_in_bytes: int

        :param data_written_in_bytes:
            The value to assign to the data_written_in_bytes property of this Run.
        :type data_written_in_bytes: int

        :param defined_tags:
            The value to assign to the defined_tags property of this Run.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this Run.
        :type display_name: str

        :param driver_shape:
            The value to assign to the driver_shape property of this Run.
        :type driver_shape: str

        :param executor_shape:
            The value to assign to the executor_shape property of this Run.
        :type executor_shape: str

        :param file_uri:
            The value to assign to the file_uri property of this Run.
        :type file_uri: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Run.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this Run.
        :type id: str

        :param language:
            The value to assign to the language property of this Run.
            Allowed values for this property are: "SCALA", "JAVA", "PYTHON", "SQL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type language: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this Run.
        :type lifecycle_details: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Run.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "CANCELING", "CANCELED", "FAILED", "SUCCEEDED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param logs_bucket_uri:
            The value to assign to the logs_bucket_uri property of this Run.
        :type logs_bucket_uri: str

        :param num_executors:
            The value to assign to the num_executors property of this Run.
        :type num_executors: int

        :param opc_request_id:
            The value to assign to the opc_request_id property of this Run.
        :type opc_request_id: str

        :param owner_principal_id:
            The value to assign to the owner_principal_id property of this Run.
        :type owner_principal_id: str

        :param owner_user_name:
            The value to assign to the owner_user_name property of this Run.
        :type owner_user_name: str

        :param parameters:
            The value to assign to the parameters property of this Run.
        :type parameters: list[ApplicationParameter]

        :param private_endpoint_dns_zones:
            The value to assign to the private_endpoint_dns_zones property of this Run.
        :type private_endpoint_dns_zones: list[str]

        :param private_endpoint_max_host_count:
            The value to assign to the private_endpoint_max_host_count property of this Run.
        :type private_endpoint_max_host_count: int

        :param private_endpoint_nsg_ids:
            The value to assign to the private_endpoint_nsg_ids property of this Run.
        :type private_endpoint_nsg_ids: list[str]

        :param private_endpoint_id:
            The value to assign to the private_endpoint_id property of this Run.
        :type private_endpoint_id: str

        :param private_endpoint_subnet_id:
            The value to assign to the private_endpoint_subnet_id property of this Run.
        :type private_endpoint_subnet_id: str

        :param run_duration_in_milliseconds:
            The value to assign to the run_duration_in_milliseconds property of this Run.
        :type run_duration_in_milliseconds: int

        :param spark_version:
            The value to assign to the spark_version property of this Run.
        :type spark_version: str

        :param time_created:
            The value to assign to the time_created property of this Run.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Run.
        :type time_updated: datetime

        :param total_o_cpu:
            The value to assign to the total_o_cpu property of this Run.
        :type total_o_cpu: int

        :param warehouse_bucket_uri:
            The value to assign to the warehouse_bucket_uri property of this Run.
        :type warehouse_bucket_uri: str

        """
        self.swagger_types = {
            'archive_uri': 'str',
            'arguments': 'list[str]',
            'application_id': 'str',
            'class_name': 'str',
            'compartment_id': 'str',
            'configuration': 'dict(str, str)',
            'data_read_in_bytes': 'int',
            'data_written_in_bytes': 'int',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'driver_shape': 'str',
            'executor_shape': 'str',
            'file_uri': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'language': 'str',
            'lifecycle_details': 'str',
            'lifecycle_state': 'str',
            'logs_bucket_uri': 'str',
            'num_executors': 'int',
            'opc_request_id': 'str',
            'owner_principal_id': 'str',
            'owner_user_name': 'str',
            'parameters': 'list[ApplicationParameter]',
            'private_endpoint_dns_zones': 'list[str]',
            'private_endpoint_max_host_count': 'int',
            'private_endpoint_nsg_ids': 'list[str]',
            'private_endpoint_id': 'str',
            'private_endpoint_subnet_id': 'str',
            'run_duration_in_milliseconds': 'int',
            'spark_version': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'total_o_cpu': 'int',
            'warehouse_bucket_uri': 'str'
        }

        self.attribute_map = {
            'archive_uri': 'archiveUri',
            'arguments': 'arguments',
            'application_id': 'applicationId',
            'class_name': 'className',
            'compartment_id': 'compartmentId',
            'configuration': 'configuration',
            'data_read_in_bytes': 'dataReadInBytes',
            'data_written_in_bytes': 'dataWrittenInBytes',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'driver_shape': 'driverShape',
            'executor_shape': 'executorShape',
            'file_uri': 'fileUri',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'language': 'language',
            'lifecycle_details': 'lifecycleDetails',
            'lifecycle_state': 'lifecycleState',
            'logs_bucket_uri': 'logsBucketUri',
            'num_executors': 'numExecutors',
            'opc_request_id': 'opcRequestId',
            'owner_principal_id': 'ownerPrincipalId',
            'owner_user_name': 'ownerUserName',
            'parameters': 'parameters',
            'private_endpoint_dns_zones': 'privateEndpointDnsZones',
            'private_endpoint_max_host_count': 'privateEndpointMaxHostCount',
            'private_endpoint_nsg_ids': 'privateEndpointNsgIds',
            'private_endpoint_id': 'privateEndpointId',
            'private_endpoint_subnet_id': 'privateEndpointSubnetId',
            'run_duration_in_milliseconds': 'runDurationInMilliseconds',
            'spark_version': 'sparkVersion',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'total_o_cpu': 'totalOCpu',
            'warehouse_bucket_uri': 'warehouseBucketUri'
        }

        self._archive_uri = None
        self._arguments = None
        self._application_id = None
        self._class_name = None
        self._compartment_id = None
        self._configuration = None
        self._data_read_in_bytes = None
        self._data_written_in_bytes = None
        self._defined_tags = None
        self._display_name = None
        self._driver_shape = None
        self._executor_shape = None
        self._file_uri = None
        self._freeform_tags = None
        self._id = None
        self._language = None
        self._lifecycle_details = None
        self._lifecycle_state = None
        self._logs_bucket_uri = None
        self._num_executors = None
        self._opc_request_id = None
        self._owner_principal_id = None
        self._owner_user_name = None
        self._parameters = None
        self._private_endpoint_dns_zones = None
        self._private_endpoint_max_host_count = None
        self._private_endpoint_nsg_ids = None
        self._private_endpoint_id = None
        self._private_endpoint_subnet_id = None
        self._run_duration_in_milliseconds = None
        self._spark_version = None
        self._time_created = None
        self._time_updated = None
        self._total_o_cpu = None
        self._warehouse_bucket_uri = None

    @property
    def archive_uri(self):
        """
        Gets the archive_uri of this Run.
        An Oracle Cloud Infrastructure URI of an archive.zip file containing custom dependencies that may be used to support the execution a Python, Java, or Scala application.
        See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :return: The archive_uri of this Run.
        :rtype: str
        """
        return self._archive_uri

    @archive_uri.setter
    def archive_uri(self, archive_uri):
        """
        Sets the archive_uri of this Run.
        An Oracle Cloud Infrastructure URI of an archive.zip file containing custom dependencies that may be used to support the execution a Python, Java, or Scala application.
        See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :param archive_uri: The archive_uri of this Run.
        :type: str
        """
        self._archive_uri = archive_uri

    @property
    def arguments(self):
        """
        Gets the arguments of this Run.
        The arguments passed to the running application as command line arguments.  An argument is
        either a plain text or a placeholder. Placeholders are replaced using values from the parameters
        map.  Each placeholder specified must be represented in the parameters map else the request
        (POST or PUT) will fail with a HTTP 400 status code.  Placeholders are specified as
        `Service Api Spec`, where `name` is the name of the parameter.
        Example:  `[ \"--input\", \"${input_file}\", \"--name\", \"John Doe\" ]`
        If \"input_file\" has a value of \"mydata.xml\", then the value above will be translated to
        `--input mydata.xml --name \"John Doe\"`


        :return: The arguments of this Run.
        :rtype: list[str]
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """
        Sets the arguments of this Run.
        The arguments passed to the running application as command line arguments.  An argument is
        either a plain text or a placeholder. Placeholders are replaced using values from the parameters
        map.  Each placeholder specified must be represented in the parameters map else the request
        (POST or PUT) will fail with a HTTP 400 status code.  Placeholders are specified as
        `Service Api Spec`, where `name` is the name of the parameter.
        Example:  `[ \"--input\", \"${input_file}\", \"--name\", \"John Doe\" ]`
        If \"input_file\" has a value of \"mydata.xml\", then the value above will be translated to
        `--input mydata.xml --name \"John Doe\"`


        :param arguments: The arguments of this Run.
        :type: list[str]
        """
        self._arguments = arguments

    @property
    def application_id(self):
        """
        **[Required]** Gets the application_id of this Run.
        The application ID.


        :return: The application_id of this Run.
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """
        Sets the application_id of this Run.
        The application ID.


        :param application_id: The application_id of this Run.
        :type: str
        """
        self._application_id = application_id

    @property
    def class_name(self):
        """
        Gets the class_name of this Run.
        The class for the application.


        :return: The class_name of this Run.
        :rtype: str
        """
        return self._class_name

    @class_name.setter
    def class_name(self, class_name):
        """
        Sets the class_name of this Run.
        The class for the application.


        :param class_name: The class_name of this Run.
        :type: str
        """
        self._class_name = class_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Run.
        The OCID of a compartment.


        :return: The compartment_id of this Run.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Run.
        The OCID of a compartment.


        :param compartment_id: The compartment_id of this Run.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def configuration(self):
        """
        Gets the configuration of this Run.
        The Spark configuration passed to the running process.
        See https://spark.apache.org/docs/latest/configuration.html#available-properties.
        Example: { \"spark.app.name\" : \"My App Name\", \"spark.shuffle.io.maxRetries\" : \"4\" }
        Note: Not all Spark properties are permitted to be set.  Attempting to set a property that is
        not allowed to be overwritten will cause a 400 status to be returned.


        :return: The configuration of this Run.
        :rtype: dict(str, str)
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """
        Sets the configuration of this Run.
        The Spark configuration passed to the running process.
        See https://spark.apache.org/docs/latest/configuration.html#available-properties.
        Example: { \"spark.app.name\" : \"My App Name\", \"spark.shuffle.io.maxRetries\" : \"4\" }
        Note: Not all Spark properties are permitted to be set.  Attempting to set a property that is
        not allowed to be overwritten will cause a 400 status to be returned.


        :param configuration: The configuration of this Run.
        :type: dict(str, str)
        """
        self._configuration = configuration

    @property
    def data_read_in_bytes(self):
        """
        Gets the data_read_in_bytes of this Run.
        The data read by the run in bytes.


        :return: The data_read_in_bytes of this Run.
        :rtype: int
        """
        return self._data_read_in_bytes

    @data_read_in_bytes.setter
    def data_read_in_bytes(self, data_read_in_bytes):
        """
        Sets the data_read_in_bytes of this Run.
        The data read by the run in bytes.


        :param data_read_in_bytes: The data_read_in_bytes of this Run.
        :type: int
        """
        self._data_read_in_bytes = data_read_in_bytes

    @property
    def data_written_in_bytes(self):
        """
        Gets the data_written_in_bytes of this Run.
        The data written by the run in bytes.


        :return: The data_written_in_bytes of this Run.
        :rtype: int
        """
        return self._data_written_in_bytes

    @data_written_in_bytes.setter
    def data_written_in_bytes(self, data_written_in_bytes):
        """
        Sets the data_written_in_bytes of this Run.
        The data written by the run in bytes.


        :param data_written_in_bytes: The data_written_in_bytes of this Run.
        :type: int
        """
        self._data_written_in_bytes = data_written_in_bytes

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Run.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Run.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Run.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Run.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this Run.
        A user-friendly name. This name is not necessarily unique.


        :return: The display_name of this Run.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Run.
        A user-friendly name. This name is not necessarily unique.


        :param display_name: The display_name of this Run.
        :type: str
        """
        self._display_name = display_name

    @property
    def driver_shape(self):
        """
        **[Required]** Gets the driver_shape of this Run.
        The VM shape for the driver. Sets the driver cores and memory.


        :return: The driver_shape of this Run.
        :rtype: str
        """
        return self._driver_shape

    @driver_shape.setter
    def driver_shape(self, driver_shape):
        """
        Sets the driver_shape of this Run.
        The VM shape for the driver. Sets the driver cores and memory.


        :param driver_shape: The driver_shape of this Run.
        :type: str
        """
        self._driver_shape = driver_shape

    @property
    def executor_shape(self):
        """
        **[Required]** Gets the executor_shape of this Run.
        The VM shape for the executors. Sets the executor cores and memory.


        :return: The executor_shape of this Run.
        :rtype: str
        """
        return self._executor_shape

    @executor_shape.setter
    def executor_shape(self, executor_shape):
        """
        Sets the executor_shape of this Run.
        The VM shape for the executors. Sets the executor cores and memory.


        :param executor_shape: The executor_shape of this Run.
        :type: str
        """
        self._executor_shape = executor_shape

    @property
    def file_uri(self):
        """
        **[Required]** Gets the file_uri of this Run.
        An Oracle Cloud Infrastructure URI of the file containing the application to execute.
        See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :return: The file_uri of this Run.
        :rtype: str
        """
        return self._file_uri

    @file_uri.setter
    def file_uri(self, file_uri):
        """
        Sets the file_uri of this Run.
        An Oracle Cloud Infrastructure URI of the file containing the application to execute.
        See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :param file_uri: The file_uri of this Run.
        :type: str
        """
        self._file_uri = file_uri

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Run.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Run.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Run.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Run.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Run.
        The ID of a run.


        :return: The id of this Run.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Run.
        The ID of a run.


        :param id: The id of this Run.
        :type: str
        """
        self._id = id

    @property
    def language(self):
        """
        **[Required]** Gets the language of this Run.
        The Spark language.

        Allowed values for this property are: "SCALA", "JAVA", "PYTHON", "SQL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The language of this Run.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this Run.
        The Spark language.


        :param language: The language of this Run.
        :type: str
        """
        allowed_values = ["SCALA", "JAVA", "PYTHON", "SQL"]
        if not value_allowed_none_or_none_sentinel(language, allowed_values):
            language = 'UNKNOWN_ENUM_VALUE'
        self._language = language

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this Run.
        The detailed messages about the lifecycle state.


        :return: The lifecycle_details of this Run.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this Run.
        The detailed messages about the lifecycle state.


        :param lifecycle_details: The lifecycle_details of this Run.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this Run.
        The current state of this run.

        Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "CANCELING", "CANCELED", "FAILED", "SUCCEEDED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Run.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Run.
        The current state of this run.


        :param lifecycle_state: The lifecycle_state of this Run.
        :type: str
        """
        allowed_values = ["ACCEPTED", "IN_PROGRESS", "CANCELING", "CANCELED", "FAILED", "SUCCEEDED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def logs_bucket_uri(self):
        """
        Gets the logs_bucket_uri of this Run.
        An Oracle Cloud Infrastructure URI of the bucket where the Spark job logs are to be uploaded.
        See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :return: The logs_bucket_uri of this Run.
        :rtype: str
        """
        return self._logs_bucket_uri

    @logs_bucket_uri.setter
    def logs_bucket_uri(self, logs_bucket_uri):
        """
        Sets the logs_bucket_uri of this Run.
        An Oracle Cloud Infrastructure URI of the bucket where the Spark job logs are to be uploaded.
        See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :param logs_bucket_uri: The logs_bucket_uri of this Run.
        :type: str
        """
        self._logs_bucket_uri = logs_bucket_uri

    @property
    def num_executors(self):
        """
        **[Required]** Gets the num_executors of this Run.
        The number of executor VMs requested.


        :return: The num_executors of this Run.
        :rtype: int
        """
        return self._num_executors

    @num_executors.setter
    def num_executors(self, num_executors):
        """
        Sets the num_executors of this Run.
        The number of executor VMs requested.


        :param num_executors: The num_executors of this Run.
        :type: int
        """
        self._num_executors = num_executors

    @property
    def opc_request_id(self):
        """
        Gets the opc_request_id of this Run.
        Unique Oracle assigned identifier for the request.
        If you need to contact Oracle about a particular request, please provide the request ID.


        :return: The opc_request_id of this Run.
        :rtype: str
        """
        return self._opc_request_id

    @opc_request_id.setter
    def opc_request_id(self, opc_request_id):
        """
        Sets the opc_request_id of this Run.
        Unique Oracle assigned identifier for the request.
        If you need to contact Oracle about a particular request, please provide the request ID.


        :param opc_request_id: The opc_request_id of this Run.
        :type: str
        """
        self._opc_request_id = opc_request_id

    @property
    def owner_principal_id(self):
        """
        Gets the owner_principal_id of this Run.
        The OCID of the user who created the resource.


        :return: The owner_principal_id of this Run.
        :rtype: str
        """
        return self._owner_principal_id

    @owner_principal_id.setter
    def owner_principal_id(self, owner_principal_id):
        """
        Sets the owner_principal_id of this Run.
        The OCID of the user who created the resource.


        :param owner_principal_id: The owner_principal_id of this Run.
        :type: str
        """
        self._owner_principal_id = owner_principal_id

    @property
    def owner_user_name(self):
        """
        Gets the owner_user_name of this Run.
        The username of the user who created the resource.  If the username of the owner does not exist,
        `null` will be returned and the caller should refer to the ownerPrincipalId value instead.


        :return: The owner_user_name of this Run.
        :rtype: str
        """
        return self._owner_user_name

    @owner_user_name.setter
    def owner_user_name(self, owner_user_name):
        """
        Sets the owner_user_name of this Run.
        The username of the user who created the resource.  If the username of the owner does not exist,
        `null` will be returned and the caller should refer to the ownerPrincipalId value instead.


        :param owner_user_name: The owner_user_name of this Run.
        :type: str
        """
        self._owner_user_name = owner_user_name

    @property
    def parameters(self):
        """
        Gets the parameters of this Run.
        An array of name/value pairs used to fill placeholders found in properties like
        `Application.arguments`.  The name must be a string of one or more word characters
        (a-z, A-Z, 0-9, _).  The value can be a string of 0 or more characters of any kind.
        Example:  [ { name: \"iterations\", value: \"10\"}, { name: \"input_file\", value: \"mydata.xml\" }, { name: \"variable_x\", value: \"${x}\"} ]


        :return: The parameters of this Run.
        :rtype: list[ApplicationParameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this Run.
        An array of name/value pairs used to fill placeholders found in properties like
        `Application.arguments`.  The name must be a string of one or more word characters
        (a-z, A-Z, 0-9, _).  The value can be a string of 0 or more characters of any kind.
        Example:  [ { name: \"iterations\", value: \"10\"}, { name: \"input_file\", value: \"mydata.xml\" }, { name: \"variable_x\", value: \"${x}\"} ]


        :param parameters: The parameters of this Run.
        :type: list[ApplicationParameter]
        """
        self._parameters = parameters

    @property
    def private_endpoint_dns_zones(self):
        """
        Gets the private_endpoint_dns_zones of this Run.
        An array of DNS zone names.
        Example: `[ \"app.examplecorp.com\", \"app.examplecorp2.com\" ]`


        :return: The private_endpoint_dns_zones of this Run.
        :rtype: list[str]
        """
        return self._private_endpoint_dns_zones

    @private_endpoint_dns_zones.setter
    def private_endpoint_dns_zones(self, private_endpoint_dns_zones):
        """
        Sets the private_endpoint_dns_zones of this Run.
        An array of DNS zone names.
        Example: `[ \"app.examplecorp.com\", \"app.examplecorp2.com\" ]`


        :param private_endpoint_dns_zones: The private_endpoint_dns_zones of this Run.
        :type: list[str]
        """
        self._private_endpoint_dns_zones = private_endpoint_dns_zones

    @property
    def private_endpoint_max_host_count(self):
        """
        Gets the private_endpoint_max_host_count of this Run.
        The maximum number of hosts to be accessed through the private endpoint. This value is used
        to calculate the relevant CIDR block and should be a multiple of 256.  If the value is not a
        multiple of 256, it is rounded up to the next multiple of 256. For example, 300 is rounded up
        to 512.


        :return: The private_endpoint_max_host_count of this Run.
        :rtype: int
        """
        return self._private_endpoint_max_host_count

    @private_endpoint_max_host_count.setter
    def private_endpoint_max_host_count(self, private_endpoint_max_host_count):
        """
        Sets the private_endpoint_max_host_count of this Run.
        The maximum number of hosts to be accessed through the private endpoint. This value is used
        to calculate the relevant CIDR block and should be a multiple of 256.  If the value is not a
        multiple of 256, it is rounded up to the next multiple of 256. For example, 300 is rounded up
        to 512.


        :param private_endpoint_max_host_count: The private_endpoint_max_host_count of this Run.
        :type: int
        """
        self._private_endpoint_max_host_count = private_endpoint_max_host_count

    @property
    def private_endpoint_nsg_ids(self):
        """
        Gets the private_endpoint_nsg_ids of this Run.
        An array of network security group OCIDs.


        :return: The private_endpoint_nsg_ids of this Run.
        :rtype: list[str]
        """
        return self._private_endpoint_nsg_ids

    @private_endpoint_nsg_ids.setter
    def private_endpoint_nsg_ids(self, private_endpoint_nsg_ids):
        """
        Sets the private_endpoint_nsg_ids of this Run.
        An array of network security group OCIDs.


        :param private_endpoint_nsg_ids: The private_endpoint_nsg_ids of this Run.
        :type: list[str]
        """
        self._private_endpoint_nsg_ids = private_endpoint_nsg_ids

    @property
    def private_endpoint_id(self):
        """
        Gets the private_endpoint_id of this Run.
        The OCID of a private endpoint.


        :return: The private_endpoint_id of this Run.
        :rtype: str
        """
        return self._private_endpoint_id

    @private_endpoint_id.setter
    def private_endpoint_id(self, private_endpoint_id):
        """
        Sets the private_endpoint_id of this Run.
        The OCID of a private endpoint.


        :param private_endpoint_id: The private_endpoint_id of this Run.
        :type: str
        """
        self._private_endpoint_id = private_endpoint_id

    @property
    def private_endpoint_subnet_id(self):
        """
        Gets the private_endpoint_subnet_id of this Run.
        The OCID of a subnet.


        :return: The private_endpoint_subnet_id of this Run.
        :rtype: str
        """
        return self._private_endpoint_subnet_id

    @private_endpoint_subnet_id.setter
    def private_endpoint_subnet_id(self, private_endpoint_subnet_id):
        """
        Sets the private_endpoint_subnet_id of this Run.
        The OCID of a subnet.


        :param private_endpoint_subnet_id: The private_endpoint_subnet_id of this Run.
        :type: str
        """
        self._private_endpoint_subnet_id = private_endpoint_subnet_id

    @property
    def run_duration_in_milliseconds(self):
        """
        Gets the run_duration_in_milliseconds of this Run.
        The duration of the run in milliseconds.


        :return: The run_duration_in_milliseconds of this Run.
        :rtype: int
        """
        return self._run_duration_in_milliseconds

    @run_duration_in_milliseconds.setter
    def run_duration_in_milliseconds(self, run_duration_in_milliseconds):
        """
        Sets the run_duration_in_milliseconds of this Run.
        The duration of the run in milliseconds.


        :param run_duration_in_milliseconds: The run_duration_in_milliseconds of this Run.
        :type: int
        """
        self._run_duration_in_milliseconds = run_duration_in_milliseconds

    @property
    def spark_version(self):
        """
        **[Required]** Gets the spark_version of this Run.
        The Spark version utilized to run the application.


        :return: The spark_version of this Run.
        :rtype: str
        """
        return self._spark_version

    @spark_version.setter
    def spark_version(self, spark_version):
        """
        Sets the spark_version of this Run.
        The Spark version utilized to run the application.


        :param spark_version: The spark_version of this Run.
        :type: str
        """
        self._spark_version = spark_version

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this Run.
        The date and time a application was created, expressed in `RFC 3339`__ timestamp format.
        Example: `2018-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Run.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Run.
        The date and time a application was created, expressed in `RFC 3339`__ timestamp format.
        Example: `2018-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Run.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this Run.
        The date and time a application was updated, expressed in `RFC 3339`__ timestamp format.
        Example: `2018-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this Run.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Run.
        The date and time a application was updated, expressed in `RFC 3339`__ timestamp format.
        Example: `2018-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this Run.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def total_o_cpu(self):
        """
        Gets the total_o_cpu of this Run.
        The total number of oCPU requested by the run.


        :return: The total_o_cpu of this Run.
        :rtype: int
        """
        return self._total_o_cpu

    @total_o_cpu.setter
    def total_o_cpu(self, total_o_cpu):
        """
        Sets the total_o_cpu of this Run.
        The total number of oCPU requested by the run.


        :param total_o_cpu: The total_o_cpu of this Run.
        :type: int
        """
        self._total_o_cpu = total_o_cpu

    @property
    def warehouse_bucket_uri(self):
        """
        Gets the warehouse_bucket_uri of this Run.
        An Oracle Cloud Infrastructure URI of the bucket to be used as default warehouse directory
        for BATCH SQL runs.
        See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :return: The warehouse_bucket_uri of this Run.
        :rtype: str
        """
        return self._warehouse_bucket_uri

    @warehouse_bucket_uri.setter
    def warehouse_bucket_uri(self, warehouse_bucket_uri):
        """
        Sets the warehouse_bucket_uri of this Run.
        An Oracle Cloud Infrastructure URI of the bucket to be used as default warehouse directory
        for BATCH SQL runs.
        See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :param warehouse_bucket_uri: The warehouse_bucket_uri of this Run.
        :type: str
        """
        self._warehouse_bucket_uri = warehouse_bucket_uri

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
